"""


Mesh Select Mode Items
^^^^^^^^^^^^^^^^^^^^^^

:VERT:            
  Vertex.

  Vertex selection mode.

:EDGE:            
  Edge.

  Edge selection mode.

:FACE:            
  Face.

  Face selection mode.

.. _rna-enum-mesh-select-mode-items:

"""

import typing



"""


Volume Grid Data Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:BOOLEAN:         
  Boolean.

  Boolean.

:FLOAT:           
  Float.

  Single precision float.

:DOUBLE:          
  Double.

  Double precision.

:INT:             
  Integer.

  32-bit integer.

:INT64:           
  Integer 64-bit.

  64-bit integer.

:MASK:            
  Mask.

  No data, boolean mask of active voxels.

:VECTOR_FLOAT:    
  Float Vector.

  3D float vector.

:VECTOR_DOUBLE:   
  Double Vector.

  3D double vector.

:VECTOR_INT:      
  Integer Vector.

  3D integer vector.

:POINTS:          
  Points (Unsupported).

  Points grid, currently unsupported by volume objects.

:UNKNOWN:         
  Unknown.

  Unsupported data type.

.. _rna-enum-volume-grid-data-type-items:

"""

import typing



"""


Keying Flag Items Api
^^^^^^^^^^^^^^^^^^^^^

:INSERTKEY_NEEDED:
  Only Needed.

  Only insert keyframes where they're needed in the relevant F-Curves.

:INSERTKEY_VISUAL:
  Visual Keying.

  Insert keyframes based on 'visual transforms'.

:INSERTKEY_XYZ_TO_RGB:
  XYZ=RGB Colors.

  Color for newly added transformation F-Curves (Location, Rotation, Scale) and also Color is based on the transform axis.

:INSERTKEY_REPLACE:
  Replace Existing.

  Only replace existing keyframes.

:INSERTKEY_AVAILABLE:
  Only Available.

  Don't create F-Curves when they don't already exist.

:INSERTKEY_CYCLE_AWARE:
  Cycle Aware Keying.

  When inserting into a curve with cyclic extrapolation, remap the keyframe inside the cycle time range, and if changing an end key, also update the other one.

.. _rna-enum-keying-flag-items-api:

"""

import typing



"""


BMesh Geometry Utilities (bmesh.geometry)
*****************************************

This module provides access to bmesh geometry evaluation functions.

:func:`intersect_face_point`

"""

import typing

import bmesh

def intersect_face_point(self, face: bmesh.types.BMFace, point: float) -> bool:

  """

  Tests if the projection of a point is inside a face (using the face's normal).

  """

  ...



"""


Boidrule Type Items
^^^^^^^^^^^^^^^^^^^

:GOAL:            
  Goal.

  Go to assigned object or loudest assigned signal source.

:AVOID:           
  Avoid.

  Get away from assigned object or loudest assigned signal source.

:AVOID_COLLISION: 
  Avoid Collision.

  Maneuver to avoid collisions with other boids and deflector objects in near future.

:SEPARATE:        
  Separate.

  Keep from going through other boids.

:FLOCK:           
  Flock.

  Move to center of neighbors and match their velocity.

:FOLLOW_LEADER:   
  Follow Leader.

  Follow a boid or assigned object.

:AVERAGE_SPEED:   
  Average Speed.

  Maintain speed, flight level or wander.

:FIGHT:           
  Fight.

  Go to closest enemy and attack when in range.

.. _rna-enum-boidrule-type-items:

"""

import typing



"""


Views Format Multiview Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:INDIVIDUAL:      
  Individual.

  Individual files for each view with the prefix as defined by the scene views.

:STEREO_3D:       
  Stereo 3D.

  Single file with an encoded stereo pair.

:MULTIVIEW:       
  Multi-View.

  Single file with all the views.

.. _rna-enum-views-format-multiview-items:

"""

import typing



"""


Icon Items
^^^^^^^^^^

:NONE:            
  NONE.

:QUESTION:        
  QUESTION.

:ERROR:           
  ERROR.

:CANCEL:          
  CANCEL.

:TRIA_RIGHT:      
  TRIA_RIGHT.

:TRIA_DOWN:       
  TRIA_DOWN.

:TRIA_LEFT:       
  TRIA_LEFT.

:TRIA_UP:         
  TRIA_UP.

:ARROW_LEFTRIGHT: 
  ARROW_LEFTRIGHT.

:PLUS:            
  PLUS.

:DISCLOSURE_TRI_RIGHT:
  DISCLOSURE_TRI_RIGHT.

:DISCLOSURE_TRI_DOWN:
  DISCLOSURE_TRI_DOWN.

:RADIOBUT_OFF:    
  RADIOBUT_OFF.

:RADIOBUT_ON:     
  RADIOBUT_ON.

:MENU_PANEL:      
  MENU_PANEL.

:BLENDER:         
  BLENDER.

:GRIP:            
  GRIP.

:DOT:             
  DOT.

:COLLAPSEMENU:    
  COLLAPSEMENU.

:X:               
:DUPLICATE:       
  DUPLICATE.

:TRASH:           
  TRASH.

:COLLECTION_NEW:  
  COLLECTION_NEW.

:OPTIONS:         
  OPTIONS.

:NODE:            
  NODE.

:NODE_SEL:        
  NODE_SEL.

:WINDOW:          
  WINDOW.

:WORKSPACE:       
  WORKSPACE.

:RIGHTARROW_THIN: 
  RIGHTARROW_THIN.

:BORDERMOVE:      
  BORDERMOVE.

:VIEWZOOM:        
  VIEWZOOM.

:ADD:             
  ADD.

:REMOVE:          
  REMOVE.

:PANEL_CLOSE:     
  PANEL_CLOSE.

:COPY_ID:         
  COPY_ID.

:EYEDROPPER:      
  EYEDROPPER.

:CHECKMARK:       
  CHECKMARK.

:AUTO:            
  AUTO.

:CHECKBOX_DEHLT:  
  CHECKBOX_DEHLT.

:CHECKBOX_HLT:    
  CHECKBOX_HLT.

:UNLOCKED:        
  UNLOCKED.

:LOCKED:          
  LOCKED.

:UNPINNED:        
  UNPINNED.

:PINNED:          
  PINNED.

:SCREEN_BACK:     
  SCREEN_BACK.

:RIGHTARROW:      
  RIGHTARROW.

:DOWNARROW_HLT:   
  DOWNARROW_HLT.

:FCURVE_SNAPSHOT: 
  FCURVE_SNAPSHOT.

:OBJECT_HIDDEN:   
  OBJECT_HIDDEN.

:TOPBAR:          
  TOPBAR.

:STATUSBAR:       
  STATUSBAR.

:PLUGIN:          
  PLUGIN.

:HELP:            
  HELP.

:GHOST_ENABLED:   
  GHOST_ENABLED.

:COLOR:           
  COLOR.

:UNLINKED:        
  UNLINKED.

:LINKED:          
  LINKED.

:HAND:            
  HAND.

:ZOOM_ALL:        
  ZOOM_ALL.

:ZOOM_SELECTED:   
  ZOOM_SELECTED.

:ZOOM_PREVIOUS:   
  ZOOM_PREVIOUS.

:ZOOM_IN:         
  ZOOM_IN.

:ZOOM_OUT:        
  ZOOM_OUT.

:DRIVER_DISTANCE: 
  DRIVER_DISTANCE.

:DRIVER_ROTATIONAL_DIFFERENCE:
  DRIVER_ROTATIONAL_DIFFERENCE.

:DRIVER_TRANSFORM:
  DRIVER_TRANSFORM.

:FREEZE:          
  FREEZE.

:STYLUS_PRESSURE: 
  STYLUS_PRESSURE.

:GHOST_DISABLED:  
  GHOST_DISABLED.

:FILE_NEW:        
  FILE_NEW.

:FILE_TICK:       
  FILE_TICK.

:QUIT:            
  QUIT.

:URL:             
  URL.

:RECOVER_LAST:    
  RECOVER_LAST.

:THREE_DOTS:      
  THREE_DOTS.

:FULLSCREEN_ENTER:
  FULLSCREEN_ENTER.

:FULLSCREEN_EXIT: 
  FULLSCREEN_EXIT.

:BRUSHES_ALL:     
  BRUSHES_ALL.

:LIGHT:           
  LIGHT.

:MATERIAL:        
  MATERIAL.

:TEXTURE:         
  TEXTURE.

:ANIM:            
  ANIM.

:WORLD:           
  WORLD.

:SCENE:           
  SCENE.

:OUTPUT:          
  OUTPUT.

:SCRIPT:          
  SCRIPT.

:PARTICLES:       
  PARTICLES.

:PHYSICS:         
  PHYSICS.

:SPEAKER:         
  SPEAKER.

:TOOL_SETTINGS:   
  TOOL_SETTINGS.

:SHADERFX:        
  SHADERFX.

:MODIFIER:        
  MODIFIER.

:BLANK1:          
  BLANK1.

:FAKE_USER_OFF:   
  FAKE_USER_OFF.

:FAKE_USER_ON:    
  FAKE_USER_ON.

:VIEW3D:          
  VIEW3D.

:GRAPH:           
  GRAPH.

:OUTLINER:        
  OUTLINER.

:PROPERTIES:      
  PROPERTIES.

:FILEBROWSER:     
  FILEBROWSER.

:IMAGE:           
  IMAGE.

:INFO:            
  INFO.

:SEQUENCE:        
  SEQUENCE.

:TEXT:            
  TEXT.

:SPREADSHEET:     
  SPREADSHEET.

:SOUND:           
  SOUND.

:ACTION:          
  ACTION.

:NLA:             
  NLA.

:PREFERENCES:     
  PREFERENCES.

:TIME:            
  TIME.

:NODETREE:        
  NODETREE.

:GEOMETRY_NODES:  
  GEOMETRY_NODES.

:CONSOLE:         
  CONSOLE.

:TRACKER:         
  TRACKER.

:ASSET_MANAGER:   
  ASSET_MANAGER.

:NODE_COMPOSITING:
  NODE_COMPOSITING.

:NODE_TEXTURE:    
  NODE_TEXTURE.

:NODE_MATERIAL:   
  NODE_MATERIAL.

:UV:              
  UV.

:OBJECT_DATAMODE: 
  OBJECT_DATAMODE.

:EDITMODE_HLT:    
  EDITMODE_HLT.

:UV_DATA:         
  UV_DATA.

:VPAINT_HLT:      
  VPAINT_HLT.

:TPAINT_HLT:      
  TPAINT_HLT.

:WPAINT_HLT:      
  WPAINT_HLT.

:SCULPTMODE_HLT:  
  SCULPTMODE_HLT.

:POSE_HLT:        
  POSE_HLT.

:PARTICLEMODE:    
  PARTICLEMODE.

:TRACKING:        
  TRACKING.

:TRACKING_BACKWARDS:
  TRACKING_BACKWARDS.

:TRACKING_FORWARDS:
  TRACKING_FORWARDS.

:TRACKING_BACKWARDS_SINGLE:
  TRACKING_BACKWARDS_SINGLE.

:TRACKING_FORWARDS_SINGLE:
  TRACKING_FORWARDS_SINGLE.

:TRACKING_CLEAR_BACKWARDS:
  TRACKING_CLEAR_BACKWARDS.

:TRACKING_CLEAR_FORWARDS:
  TRACKING_CLEAR_FORWARDS.

:TRACKING_REFINE_BACKWARDS:
  TRACKING_REFINE_BACKWARDS.

:TRACKING_REFINE_FORWARDS:
  TRACKING_REFINE_FORWARDS.

:SCENE_DATA:      
  SCENE_DATA.

:RENDERLAYERS:    
  RENDERLAYERS.

:WORLD_DATA:      
  WORLD_DATA.

:OBJECT_DATA:     
  OBJECT_DATA.

:MESH_DATA:       
  MESH_DATA.

:CURVE_DATA:      
  CURVE_DATA.

:META_DATA:       
  META_DATA.

:LATTICE_DATA:    
  LATTICE_DATA.

:LIGHT_DATA:      
  LIGHT_DATA.

:MATERIAL_DATA:   
  MATERIAL_DATA.

:TEXTURE_DATA:    
  TEXTURE_DATA.

:ANIM_DATA:       
  ANIM_DATA.

:CAMERA_DATA:     
  CAMERA_DATA.

:PARTICLE_DATA:   
  PARTICLE_DATA.

:LIBRARY_DATA_DIRECT:
  LIBRARY_DATA_DIRECT.

:GROUP:           
  GROUP.

:ARMATURE_DATA:   
  ARMATURE_DATA.

:COMMUNITY:       
  COMMUNITY.

:BONE_DATA:       
  BONE_DATA.

:CONSTRAINT:      
  CONSTRAINT.

:SHAPEKEY_DATA:   
  SHAPEKEY_DATA.

:CONSTRAINT_BONE: 
  CONSTRAINT_BONE.

:CAMERA_STEREO:   
  CAMERA_STEREO.

:PACKAGE:         
  PACKAGE.

:UGLYPACKAGE:     
  UGLYPACKAGE.

:EXPERIMENTAL:    
  EXPERIMENTAL.

:BRUSH_DATA:      
  BRUSH_DATA.

:IMAGE_DATA:      
  IMAGE_DATA.

:FILE:            
  FILE.

:FCURVE:          
  FCURVE.

:FONT_DATA:       
  FONT_DATA.

:RENDER_RESULT:   
  RENDER_RESULT.

:SURFACE_DATA:    
  SURFACE_DATA.

:EMPTY_DATA:      
  EMPTY_DATA.

:PRESET:          
  PRESET.

:RENDER_ANIMATION:
  RENDER_ANIMATION.

:RENDER_STILL:    
  RENDER_STILL.

:LIBRARY_DATA_BROKEN:
  LIBRARY_DATA_BROKEN.

:BOIDS:           
  BOIDS.

:STRANDS:         
  STRANDS.

:GREASEPENCIL:    
  GREASEPENCIL.

:LINE_DATA:       
  LINE_DATA.

:LIBRARY_DATA_OVERRIDE:
  LIBRARY_DATA_OVERRIDE.

:GROUP_BONE:      
  GROUP_BONE.

:GROUP_VERTEX:    
  GROUP_VERTEX.

:GROUP_VCOL:      
  GROUP_VCOL.

:GROUP_UVS:       
  GROUP_UVS.

:FACE_MAPS:       
  FACE_MAPS.

:RNA:             
  RNA.

:RNA_ADD:         
  RNA_ADD.

:MOUSE_LMB:       
  MOUSE_LMB.

:MOUSE_MMB:       
  MOUSE_MMB.

:MOUSE_RMB:       
  MOUSE_RMB.

:MOUSE_MOVE:      
  MOUSE_MOVE.

:MOUSE_LMB_DRAG:  
  MOUSE_LMB_DRAG.

:MOUSE_MMB_DRAG:  
  MOUSE_MMB_DRAG.

:MOUSE_RMB_DRAG:  
  MOUSE_RMB_DRAG.

:MEMORY:          
  MEMORY.

:PRESET_NEW:      
  PRESET_NEW.

:DECORATE:        
  DECORATE.

:DECORATE_KEYFRAME:
  DECORATE_KEYFRAME.

:DECORATE_ANIMATE:
  DECORATE_ANIMATE.

:DECORATE_DRIVER: 
  DECORATE_DRIVER.

:DECORATE_LINKED: 
  DECORATE_LINKED.

:DECORATE_LIBRARY_OVERRIDE:
  DECORATE_LIBRARY_OVERRIDE.

:DECORATE_UNLOCKED:
  DECORATE_UNLOCKED.

:DECORATE_LOCKED: 
  DECORATE_LOCKED.

:DECORATE_OVERRIDE:
  DECORATE_OVERRIDE.

:FUND:            
  FUND.

:TRACKER_DATA:    
  TRACKER_DATA.

:HEART:           
  HEART.

:ORPHAN_DATA:     
  ORPHAN_DATA.

:USER:            
  USER.

:SYSTEM:          
  SYSTEM.

:SETTINGS:        
  SETTINGS.

:OUTLINER_OB_EMPTY:
  OUTLINER_OB_EMPTY.

:OUTLINER_OB_MESH:
  OUTLINER_OB_MESH.

:OUTLINER_OB_CURVE:
  OUTLINER_OB_CURVE.

:OUTLINER_OB_LATTICE:
  OUTLINER_OB_LATTICE.

:OUTLINER_OB_META:
  OUTLINER_OB_META.

:OUTLINER_OB_LIGHT:
  OUTLINER_OB_LIGHT.

:OUTLINER_OB_CAMERA:
  OUTLINER_OB_CAMERA.

:OUTLINER_OB_ARMATURE:
  OUTLINER_OB_ARMATURE.

:OUTLINER_OB_FONT:
  OUTLINER_OB_FONT.

:OUTLINER_OB_SURFACE:
  OUTLINER_OB_SURFACE.

:OUTLINER_OB_SPEAKER:
  OUTLINER_OB_SPEAKER.

:OUTLINER_OB_FORCE_FIELD:
  OUTLINER_OB_FORCE_FIELD.

:OUTLINER_OB_GROUP_INSTANCE:
  OUTLINER_OB_GROUP_INSTANCE.

:OUTLINER_OB_GREASEPENCIL:
  OUTLINER_OB_GREASEPENCIL.

:OUTLINER_OB_LIGHTPROBE:
  OUTLINER_OB_LIGHTPROBE.

:OUTLINER_OB_IMAGE:
  OUTLINER_OB_IMAGE.

:OUTLINER_COLLECTION:
  OUTLINER_COLLECTION.

:RESTRICT_COLOR_OFF:
  RESTRICT_COLOR_OFF.

:RESTRICT_COLOR_ON:
  RESTRICT_COLOR_ON.

:HIDE_ON:         
  HIDE_ON.

:HIDE_OFF:        
  HIDE_OFF.

:RESTRICT_SELECT_ON:
  RESTRICT_SELECT_ON.

:RESTRICT_SELECT_OFF:
  RESTRICT_SELECT_OFF.

:RESTRICT_RENDER_ON:
  RESTRICT_RENDER_ON.

:RESTRICT_RENDER_OFF:
  RESTRICT_RENDER_OFF.

:RESTRICT_INSTANCED_OFF:
  RESTRICT_INSTANCED_OFF.

:OUTLINER_DATA_EMPTY:
  OUTLINER_DATA_EMPTY.

:OUTLINER_DATA_MESH:
  OUTLINER_DATA_MESH.

:OUTLINER_DATA_CURVE:
  OUTLINER_DATA_CURVE.

:OUTLINER_DATA_LATTICE:
  OUTLINER_DATA_LATTICE.

:OUTLINER_DATA_META:
  OUTLINER_DATA_META.

:OUTLINER_DATA_LIGHT:
  OUTLINER_DATA_LIGHT.

:OUTLINER_DATA_CAMERA:
  OUTLINER_DATA_CAMERA.

:OUTLINER_DATA_ARMATURE:
  OUTLINER_DATA_ARMATURE.

:OUTLINER_DATA_FONT:
  OUTLINER_DATA_FONT.

:OUTLINER_DATA_SURFACE:
  OUTLINER_DATA_SURFACE.

:OUTLINER_DATA_SPEAKER:
  OUTLINER_DATA_SPEAKER.

:OUTLINER_DATA_LIGHTPROBE:
  OUTLINER_DATA_LIGHTPROBE.

:OUTLINER_DATA_GP_LAYER:
  OUTLINER_DATA_GP_LAYER.

:OUTLINER_DATA_GREASEPENCIL:
  OUTLINER_DATA_GREASEPENCIL.

:GP_SELECT_POINTS:
  GP_SELECT_POINTS.

:GP_SELECT_STROKES:
  GP_SELECT_STROKES.

:GP_MULTIFRAME_EDITING:
  GP_MULTIFRAME_EDITING.

:GP_ONLY_SELECTED:
  GP_ONLY_SELECTED.

:GP_SELECT_BETWEEN_STROKES:
  GP_SELECT_BETWEEN_STROKES.

:MODIFIER_OFF:    
  MODIFIER_OFF.

:MODIFIER_ON:     
  MODIFIER_ON.

:ONIONSKIN_OFF:   
  ONIONSKIN_OFF.

:ONIONSKIN_ON:    
  ONIONSKIN_ON.

:RESTRICT_VIEW_ON:
  RESTRICT_VIEW_ON.

:RESTRICT_VIEW_OFF:
  RESTRICT_VIEW_OFF.

:RESTRICT_INSTANCED_ON:
  RESTRICT_INSTANCED_ON.

:MESH_PLANE:      
  MESH_PLANE.

:MESH_CUBE:       
  MESH_CUBE.

:MESH_CIRCLE:     
  MESH_CIRCLE.

:MESH_UVSPHERE:   
  MESH_UVSPHERE.

:MESH_ICOSPHERE:  
  MESH_ICOSPHERE.

:MESH_GRID:       
  MESH_GRID.

:MESH_MONKEY:     
  MESH_MONKEY.

:MESH_CYLINDER:   
  MESH_CYLINDER.

:MESH_TORUS:      
  MESH_TORUS.

:MESH_CONE:       
  MESH_CONE.

:MESH_CAPSULE:    
  MESH_CAPSULE.

:EMPTY_SINGLE_ARROW:
  EMPTY_SINGLE_ARROW.

:LIGHT_POINT:     
  LIGHT_POINT.

:LIGHT_SUN:       
  LIGHT_SUN.

:LIGHT_SPOT:      
  LIGHT_SPOT.

:LIGHT_HEMI:      
  LIGHT_HEMI.

:LIGHT_AREA:      
  LIGHT_AREA.

:CUBE:            
  CUBE.

:SPHERE:          
  SPHERE.

:CONE:            
  CONE.

:META_PLANE:      
  META_PLANE.

:META_CUBE:       
  META_CUBE.

:META_BALL:       
  META_BALL.

:META_ELLIPSOID:  
  META_ELLIPSOID.

:META_CAPSULE:    
  META_CAPSULE.

:SURFACE_NCURVE:  
  SURFACE_NCURVE.

:SURFACE_NCIRCLE: 
  SURFACE_NCIRCLE.

:SURFACE_NSURFACE:
  SURFACE_NSURFACE.

:SURFACE_NCYLINDER:
  SURFACE_NCYLINDER.

:SURFACE_NSPHERE: 
  SURFACE_NSPHERE.

:SURFACE_NTORUS:  
  SURFACE_NTORUS.

:EMPTY_AXIS:      
  EMPTY_AXIS.

:STROKE:          
  STROKE.

:EMPTY_ARROWS:    
  EMPTY_ARROWS.

:CURVE_BEZCURVE:  
  CURVE_BEZCURVE.

:CURVE_BEZCIRCLE: 
  CURVE_BEZCIRCLE.

:CURVE_NCURVE:    
  CURVE_NCURVE.

:CURVE_NCIRCLE:   
  CURVE_NCIRCLE.

:CURVE_PATH:      
  CURVE_PATH.

:LIGHTPROBE_CUBEMAP:
  LIGHTPROBE_CUBEMAP.

:LIGHTPROBE_PLANAR:
  LIGHTPROBE_PLANAR.

:LIGHTPROBE_GRID: 
  LIGHTPROBE_GRID.

:COLOR_RED:       
  COLOR_RED.

:COLOR_GREEN:     
  COLOR_GREEN.

:COLOR_BLUE:      
  COLOR_BLUE.

:TRIA_RIGHT_BAR:  
  TRIA_RIGHT_BAR.

:TRIA_DOWN_BAR:   
  TRIA_DOWN_BAR.

:TRIA_LEFT_BAR:   
  TRIA_LEFT_BAR.

:TRIA_UP_BAR:     
  TRIA_UP_BAR.

:FORCE_FORCE:     
  FORCE_FORCE.

:FORCE_WIND:      
  FORCE_WIND.

:FORCE_VORTEX:    
  FORCE_VORTEX.

:FORCE_MAGNETIC:  
  FORCE_MAGNETIC.

:FORCE_HARMONIC:  
  FORCE_HARMONIC.

:FORCE_CHARGE:    
  FORCE_CHARGE.

:FORCE_LENNARDJONES:
  FORCE_LENNARDJONES.

:FORCE_TEXTURE:   
  FORCE_TEXTURE.

:FORCE_CURVE:     
  FORCE_CURVE.

:FORCE_BOID:      
  FORCE_BOID.

:FORCE_TURBULENCE:
  FORCE_TURBULENCE.

:FORCE_DRAG:      
  FORCE_DRAG.

:FORCE_FLUIDFLOW: 
  FORCE_FLUIDFLOW.

:RIGID_BODY:      
  RIGID_BODY.

:RIGID_BODY_CONSTRAINT:
  RIGID_BODY_CONSTRAINT.

:IMAGE_PLANE:     
  IMAGE_PLANE.

:IMAGE_BACKGROUND:
  IMAGE_BACKGROUND.

:IMAGE_REFERENCE: 
  IMAGE_REFERENCE.

:NODE_INSERT_ON:  
  NODE_INSERT_ON.

:NODE_INSERT_OFF: 
  NODE_INSERT_OFF.

:NODE_TOP:        
  NODE_TOP.

:NODE_SIDE:       
  NODE_SIDE.

:NODE_CORNER:     
  NODE_CORNER.

:ANCHOR_TOP:      
  ANCHOR_TOP.

:ANCHOR_BOTTOM:   
  ANCHOR_BOTTOM.

:ANCHOR_LEFT:     
  ANCHOR_LEFT.

:ANCHOR_RIGHT:    
  ANCHOR_RIGHT.

:ANCHOR_CENTER:   
  ANCHOR_CENTER.

:SELECT_SET:      
  SELECT_SET.

:SELECT_EXTEND:   
  SELECT_EXTEND.

:SELECT_SUBTRACT: 
  SELECT_SUBTRACT.

:SELECT_INTERSECT:
  SELECT_INTERSECT.

:SELECT_DIFFERENCE:
  SELECT_DIFFERENCE.

:ALIGN_LEFT:      
  ALIGN_LEFT.

:ALIGN_CENTER:    
  ALIGN_CENTER.

:ALIGN_RIGHT:     
  ALIGN_RIGHT.

:ALIGN_JUSTIFY:   
  ALIGN_JUSTIFY.

:ALIGN_FLUSH:     
  ALIGN_FLUSH.

:ALIGN_TOP:       
  ALIGN_TOP.

:ALIGN_MIDDLE:    
  ALIGN_MIDDLE.

:ALIGN_BOTTOM:    
  ALIGN_BOTTOM.

:BOLD:            
  BOLD.

:ITALIC:          
  ITALIC.

:UNDERLINE:       
  UNDERLINE.

:SMALL_CAPS:      
  SMALL_CAPS.

:CON_ACTION:      
  CON_ACTION.

:MOD_ENVELOPE:    
  MOD_ENVELOPE.

:MOD_OUTLINE:     
  MOD_OUTLINE.

:MOD_LENGTH:      
  MOD_LENGTH.

:MOD_DASH:        
  MOD_DASH.

:MOD_LINEART:     
  MOD_LINEART.

:HOLDOUT_OFF:     
  HOLDOUT_OFF.

:HOLDOUT_ON:      
  HOLDOUT_ON.

:INDIRECT_ONLY_OFF:
  INDIRECT_ONLY_OFF.

:INDIRECT_ONLY_ON:
  INDIRECT_ONLY_ON.

:CON_CAMERASOLVER:
  CON_CAMERASOLVER.

:CON_FOLLOWTRACK: 
  CON_FOLLOWTRACK.

:CON_OBJECTSOLVER:
  CON_OBJECTSOLVER.

:CON_LOCLIKE:     
  CON_LOCLIKE.

:CON_ROTLIKE:     
  CON_ROTLIKE.

:CON_SIZELIKE:    
  CON_SIZELIKE.

:CON_TRANSLIKE:   
  CON_TRANSLIKE.

:CON_DISTLIMIT:   
  CON_DISTLIMIT.

:CON_LOCLIMIT:    
  CON_LOCLIMIT.

:CON_ROTLIMIT:    
  CON_ROTLIMIT.

:CON_SIZELIMIT:   
  CON_SIZELIMIT.

:CON_SAMEVOL:     
  CON_SAMEVOL.

:CON_TRANSFORM:   
  CON_TRANSFORM.

:CON_TRANSFORM_CACHE:
  CON_TRANSFORM_CACHE.

:CON_CLAMPTO:     
  CON_CLAMPTO.

:CON_KINEMATIC:   
  CON_KINEMATIC.

:CON_LOCKTRACK:   
  CON_LOCKTRACK.

:CON_SPLINEIK:    
  CON_SPLINEIK.

:CON_STRETCHTO:   
  CON_STRETCHTO.

:CON_TRACKTO:     
  CON_TRACKTO.

:CON_ARMATURE:    
  CON_ARMATURE.

:CON_CHILDOF:     
  CON_CHILDOF.

:CON_FLOOR:       
  CON_FLOOR.

:CON_FOLLOWPATH:  
  CON_FOLLOWPATH.

:CON_PIVOT:       
  CON_PIVOT.

:CON_SHRINKWRAP:  
  CON_SHRINKWRAP.

:MODIFIER_DATA:   
  MODIFIER_DATA.

:MOD_WAVE:        
  MOD_WAVE.

:MOD_BUILD:       
  MOD_BUILD.

:MOD_DECIM:       
  MOD_DECIM.

:MOD_MIRROR:      
  MOD_MIRROR.

:MOD_SOFT:        
  MOD_SOFT.

:MOD_SUBSURF:     
  MOD_SUBSURF.

:HOOK:            
  HOOK.

:MOD_PHYSICS:     
  MOD_PHYSICS.

:MOD_PARTICLES:   
  MOD_PARTICLES.

:MOD_BOOLEAN:     
  MOD_BOOLEAN.

:MOD_EDGESPLIT:   
  MOD_EDGESPLIT.

:MOD_ARRAY:       
  MOD_ARRAY.

:MOD_UVPROJECT:   
  MOD_UVPROJECT.

:MOD_DISPLACE:    
  MOD_DISPLACE.

:MOD_CURVE:       
  MOD_CURVE.

:MOD_LATTICE:     
  MOD_LATTICE.

:MOD_TINT:        
  MOD_TINT.

:MOD_ARMATURE:    
  MOD_ARMATURE.

:MOD_SHRINKWRAP:  
  MOD_SHRINKWRAP.

:MOD_CAST:        
  MOD_CAST.

:MOD_MESHDEFORM:  
  MOD_MESHDEFORM.

:MOD_BEVEL:       
  MOD_BEVEL.

:MOD_SMOOTH:      
  MOD_SMOOTH.

:MOD_SIMPLEDEFORM:
  MOD_SIMPLEDEFORM.

:MOD_MASK:        
  MOD_MASK.

:MOD_CLOTH:       
  MOD_CLOTH.

:MOD_EXPLODE:     
  MOD_EXPLODE.

:MOD_FLUIDSIM:    
  MOD_FLUIDSIM.

:MOD_MULTIRES:    
  MOD_MULTIRES.

:MOD_FLUID:       
  MOD_FLUID.

:MOD_SOLIDIFY:    
  MOD_SOLIDIFY.

:MOD_SCREW:       
  MOD_SCREW.

:MOD_VERTEX_WEIGHT:
  MOD_VERTEX_WEIGHT.

:MOD_DYNAMICPAINT:
  MOD_DYNAMICPAINT.

:MOD_REMESH:      
  MOD_REMESH.

:MOD_OCEAN:       
  MOD_OCEAN.

:MOD_WARP:        
  MOD_WARP.

:MOD_SKIN:        
  MOD_SKIN.

:MOD_TRIANGULATE: 
  MOD_TRIANGULATE.

:MOD_WIREFRAME:   
  MOD_WIREFRAME.

:MOD_DATA_TRANSFER:
  MOD_DATA_TRANSFER.

:MOD_NORMALEDIT:  
  MOD_NORMALEDIT.

:MOD_PARTICLE_INSTANCE:
  MOD_PARTICLE_INSTANCE.

:MOD_HUE_SATURATION:
  MOD_HUE_SATURATION.

:MOD_NOISE:       
  MOD_NOISE.

:MOD_OFFSET:      
  MOD_OFFSET.

:MOD_SIMPLIFY:    
  MOD_SIMPLIFY.

:MOD_THICKNESS:   
  MOD_THICKNESS.

:MOD_INSTANCE:    
  MOD_INSTANCE.

:MOD_TIME:        
  MOD_TIME.

:MOD_OPACITY:     
  MOD_OPACITY.

:REC:             
  REC.

:PLAY:            
  PLAY.

:FF:              
  FF.

:REW:             
  REW.

:PAUSE:           
  PAUSE.

:PREV_KEYFRAME:   
  PREV_KEYFRAME.

:NEXT_KEYFRAME:   
  NEXT_KEYFRAME.

:PLAY_SOUND:      
  PLAY_SOUND.

:PLAY_REVERSE:    
  PLAY_REVERSE.

:PREVIEW_RANGE:   
  PREVIEW_RANGE.

:ACTION_TWEAK:    
  ACTION_TWEAK.

:PMARKER_ACT:     
  PMARKER_ACT.

:PMARKER_SEL:     
  PMARKER_SEL.

:PMARKER:         
  PMARKER.

:MARKER_HLT:      
  MARKER_HLT.

:MARKER:          
  MARKER.

:KEYFRAME_HLT:    
  KEYFRAME_HLT.

:KEYFRAME:        
  KEYFRAME.

:KEYINGSET:       
  KEYINGSET.

:KEY_DEHLT:       
  KEY_DEHLT.

:KEY_HLT:         
  KEY_HLT.

:MUTE_IPO_OFF:    
  MUTE_IPO_OFF.

:MUTE_IPO_ON:     
  MUTE_IPO_ON.

:DRIVER:          
  DRIVER.

:SOLO_OFF:        
  SOLO_OFF.

:SOLO_ON:         
  SOLO_ON.

:FRAME_PREV:      
  FRAME_PREV.

:FRAME_NEXT:      
  FRAME_NEXT.

:NLA_PUSHDOWN:    
  NLA_PUSHDOWN.

:IPO_CONSTANT:    
  IPO_CONSTANT.

:IPO_LINEAR:      
  IPO_LINEAR.

:IPO_BEZIER:      
  IPO_BEZIER.

:IPO_SINE:        
  IPO_SINE.

:IPO_QUAD:        
  IPO_QUAD.

:IPO_CUBIC:       
  IPO_CUBIC.

:IPO_QUART:       
  IPO_QUART.

:IPO_QUINT:       
  IPO_QUINT.

:IPO_EXPO:        
  IPO_EXPO.

:IPO_CIRC:        
  IPO_CIRC.

:IPO_BOUNCE:      
  IPO_BOUNCE.

:IPO_ELASTIC:     
  IPO_ELASTIC.

:IPO_BACK:        
  IPO_BACK.

:IPO_EASE_IN:     
  IPO_EASE_IN.

:IPO_EASE_OUT:    
  IPO_EASE_OUT.

:IPO_EASE_IN_OUT: 
  IPO_EASE_IN_OUT.

:NORMALIZE_FCURVES:
  NORMALIZE_FCURVES.

:ORIENTATION_PARENT:
  ORIENTATION_PARENT.

:VERTEXSEL:       
  VERTEXSEL.

:EDGESEL:         
  EDGESEL.

:FACESEL:         
  FACESEL.

:CURSOR:          
  CURSOR.

:PIVOT_BOUNDBOX:  
  PIVOT_BOUNDBOX.

:PIVOT_CURSOR:    
  PIVOT_CURSOR.

:PIVOT_INDIVIDUAL:
  PIVOT_INDIVIDUAL.

:PIVOT_MEDIAN:    
  PIVOT_MEDIAN.

:PIVOT_ACTIVE:    
  PIVOT_ACTIVE.

:CENTER_ONLY:     
  CENTER_ONLY.

:ROOTCURVE:       
  ROOTCURVE.

:SMOOTHCURVE:     
  SMOOTHCURVE.

:SPHERECURVE:     
  SPHERECURVE.

:INVERSESQUARECURVE:
  INVERSESQUARECURVE.

:SHARPCURVE:      
  SHARPCURVE.

:LINCURVE:        
  LINCURVE.

:NOCURVE:         
  NOCURVE.

:RNDCURVE:        
  RNDCURVE.

:PROP_OFF:        
  PROP_OFF.

:PROP_ON:         
  PROP_ON.

:PROP_CON:        
  PROP_CON.

:PROP_PROJECTED:  
  PROP_PROJECTED.

:PARTICLE_POINT:  
  PARTICLE_POINT.

:PARTICLE_TIP:    
  PARTICLE_TIP.

:PARTICLE_PATH:   
  PARTICLE_PATH.

:SNAP_FACE_NEAREST:
  SNAP_FACE_NEAREST.

:SNAP_FACE_CENTER:
  SNAP_FACE_CENTER.

:SNAP_PERPENDICULAR:
  SNAP_PERPENDICULAR.

:SNAP_MIDPOINT:   
  SNAP_MIDPOINT.

:SNAP_OFF:        
  SNAP_OFF.

:SNAP_ON:         
  SNAP_ON.

:SNAP_NORMAL:     
  SNAP_NORMAL.

:SNAP_GRID:       
  SNAP_GRID.

:SNAP_VERTEX:     
  SNAP_VERTEX.

:SNAP_EDGE:       
  SNAP_EDGE.

:SNAP_FACE:       
  SNAP_FACE.

:SNAP_VOLUME:     
  SNAP_VOLUME.

:SNAP_INCREMENT:  
  SNAP_INCREMENT.

:STICKY_UVS_LOC:  
  STICKY_UVS_LOC.

:STICKY_UVS_DISABLE:
  STICKY_UVS_DISABLE.

:STICKY_UVS_VERT: 
  STICKY_UVS_VERT.

:CLIPUV_DEHLT:    
  CLIPUV_DEHLT.

:CLIPUV_HLT:      
  CLIPUV_HLT.

:SNAP_PEEL_OBJECT:
  SNAP_PEEL_OBJECT.

:GRID:            
  GRID.

:OBJECT_ORIGIN:   
  OBJECT_ORIGIN.

:ORIENTATION_GLOBAL:
  ORIENTATION_GLOBAL.

:ORIENTATION_GIMBAL:
  ORIENTATION_GIMBAL.

:ORIENTATION_LOCAL:
  ORIENTATION_LOCAL.

:ORIENTATION_NORMAL:
  ORIENTATION_NORMAL.

:ORIENTATION_VIEW:
  ORIENTATION_VIEW.

:COPYDOWN:        
  COPYDOWN.

:PASTEDOWN:       
  PASTEDOWN.

:PASTEFLIPUP:     
  PASTEFLIPUP.

:PASTEFLIPDOWN:   
  PASTEFLIPDOWN.

:VIS_SEL_11:      
  VIS_SEL_11.

:VIS_SEL_10:      
  VIS_SEL_10.

:VIS_SEL_01:      
  VIS_SEL_01.

:VIS_SEL_00:      
  VIS_SEL_00.

:AUTOMERGE_OFF:   
  AUTOMERGE_OFF.

:AUTOMERGE_ON:    
  AUTOMERGE_ON.

:UV_VERTEXSEL:    
  UV_VERTEXSEL.

:UV_EDGESEL:      
  UV_EDGESEL.

:UV_FACESEL:      
  UV_FACESEL.

:UV_ISLANDSEL:    
  UV_ISLANDSEL.

:UV_SYNC_SELECT:  
  UV_SYNC_SELECT.

:GP_CAPS_FLAT:    
  GP_CAPS_FLAT.

:GP_CAPS_ROUND:   
  GP_CAPS_ROUND.

:FIXED_SIZE:      
  FIXED_SIZE.

:TRANSFORM_ORIGINS:
  TRANSFORM_ORIGINS.

:GIZMO:           
  GIZMO.

:ORIENTATION_CURSOR:
  ORIENTATION_CURSOR.

:NORMALS_VERTEX:  
  NORMALS_VERTEX.

:NORMALS_FACE:    
  NORMALS_FACE.

:NORMALS_VERTEX_FACE:
  NORMALS_VERTEX_FACE.

:SHADING_BBOX:    
  SHADING_BBOX.

:SHADING_WIRE:    
  SHADING_WIRE.

:SHADING_SOLID:   
  SHADING_SOLID.

:SHADING_RENDERED:
  SHADING_RENDERED.

:SHADING_TEXTURE: 
  SHADING_TEXTURE.

:OVERLAY:         
  OVERLAY.

:XRAY:            
  XRAY.

:LOCKVIEW_OFF:    
  LOCKVIEW_OFF.

:LOCKVIEW_ON:     
  LOCKVIEW_ON.

:AXIS_SIDE:       
  AXIS_SIDE.

:AXIS_FRONT:      
  AXIS_FRONT.

:AXIS_TOP:        
  AXIS_TOP.

:LAYER_USED:      
  LAYER_USED.

:LAYER_ACTIVE:    
  LAYER_ACTIVE.

:OUTLINER_OB_CURVES:
  OUTLINER_OB_CURVES.

:OUTLINER_DATA_CURVES:
  OUTLINER_DATA_CURVES.

:CURVES_DATA:     
  CURVES_DATA.

:OUTLINER_OB_POINTCLOUD:
  OUTLINER_OB_POINTCLOUD.

:OUTLINER_DATA_POINTCLOUD:
  OUTLINER_DATA_POINTCLOUD.

:POINTCLOUD_DATA: 
  POINTCLOUD_DATA.

:OUTLINER_OB_VOLUME:
  OUTLINER_OB_VOLUME.

:OUTLINER_DATA_VOLUME:
  OUTLINER_DATA_VOLUME.

:VOLUME_DATA:     
  VOLUME_DATA.

:CURRENT_FILE:    
  CURRENT_FILE.

:HOME:            
  HOME.

:DOCUMENTS:       
  DOCUMENTS.

:TEMP:            
  TEMP.

:SORTALPHA:       
  SORTALPHA.

:SORTBYEXT:       
  SORTBYEXT.

:SORTTIME:        
  SORTTIME.

:SORTSIZE:        
  SORTSIZE.

:SHORTDISPLAY:    
  SHORTDISPLAY.

:LONGDISPLAY:     
  LONGDISPLAY.

:IMGDISPLAY:      
  IMGDISPLAY.

:BOOKMARKS:       
  BOOKMARKS.

:FONTPREVIEW:     
  FONTPREVIEW.

:FILTER:          
  FILTER.

:NEWFOLDER:       
  NEWFOLDER.

:FOLDER_REDIRECT: 
  FOLDER_REDIRECT.

:FILE_PARENT:     
  FILE_PARENT.

:FILE_REFRESH:    
  FILE_REFRESH.

:FILE_FOLDER:     
  FILE_FOLDER.

:FILE_BLANK:      
  FILE_BLANK.

:FILE_BLEND:      
  FILE_BLEND.

:FILE_IMAGE:      
  FILE_IMAGE.

:FILE_MOVIE:      
  FILE_MOVIE.

:FILE_SCRIPT:     
  FILE_SCRIPT.

:FILE_SOUND:      
  FILE_SOUND.

:FILE_FONT:       
  FILE_FONT.

:FILE_TEXT:       
  FILE_TEXT.

:SORT_DESC:       
  SORT_DESC.

:SORT_ASC:        
  SORT_ASC.

:LINK_BLEND:      
  LINK_BLEND.

:APPEND_BLEND:    
  APPEND_BLEND.

:IMPORT:          
  IMPORT.

:EXPORT:          
  EXPORT.

:LOOP_BACK:       
  LOOP_BACK.

:LOOP_FORWARDS:   
  LOOP_FORWARDS.

:BACK:            
  BACK.

:FORWARD:         
  FORWARD.

:FILE_ARCHIVE:    
  FILE_ARCHIVE.

:FILE_CACHE:      
  FILE_CACHE.

:FILE_VOLUME:     
  FILE_VOLUME.

:FILE_3D:         
  FILE_3D.

:FILE_HIDDEN:     
  FILE_HIDDEN.

:FILE_BACKUP:     
  FILE_BACKUP.

:DISK_DRIVE:      
  DISK_DRIVE.

:MATPLANE:        
  MATPLANE.

:MATSPHERE:       
  MATSPHERE.

:MATCUBE:         
  MATCUBE.

:MONKEY:          
  MONKEY.

:CURVES:          
  CURVES.

:ALIASED:         
  ALIASED.

:ANTIALIASED:     
  ANTIALIASED.

:MAT_SPHERE_SKY:  
  MAT_SPHERE_SKY.

:MATSHADERBALL:   
  MATSHADERBALL.

:MATCLOTH:        
  MATCLOTH.

:MATFLUID:        
  MATFLUID.

:WORDWRAP_OFF:    
  WORDWRAP_OFF.

:WORDWRAP_ON:     
  WORDWRAP_ON.

:SYNTAX_OFF:      
  SYNTAX_OFF.

:SYNTAX_ON:       
  SYNTAX_ON.

:LINENUMBERS_OFF: 
  LINENUMBERS_OFF.

:LINENUMBERS_ON:  
  LINENUMBERS_ON.

:SCRIPTPLUGINS:   
  SCRIPTPLUGINS.

:DISC:            
  DISC.

:DESKTOP:         
  DESKTOP.

:EXTERNAL_DRIVE:  
  EXTERNAL_DRIVE.

:NETWORK_DRIVE:   
  NETWORK_DRIVE.

:SEQ_SEQUENCER:   
  SEQ_SEQUENCER.

:SEQ_PREVIEW:     
  SEQ_PREVIEW.

:SEQ_LUMA_WAVEFORM:
  SEQ_LUMA_WAVEFORM.

:SEQ_CHROMA_SCOPE:
  SEQ_CHROMA_SCOPE.

:SEQ_HISTOGRAM:   
  SEQ_HISTOGRAM.

:SEQ_SPLITVIEW:   
  SEQ_SPLITVIEW.

:SEQ_STRIP_META:  
  SEQ_STRIP_META.

:SEQ_STRIP_DUPLICATE:
  SEQ_STRIP_DUPLICATE.

:IMAGE_RGB:       
  IMAGE_RGB.

:IMAGE_RGB_ALPHA: 
  IMAGE_RGB_ALPHA.

:IMAGE_ALPHA:     
  IMAGE_ALPHA.

:IMAGE_ZDEPTH:    
  IMAGE_ZDEPTH.

:HANDLE_AUTOCLAMPED:
  HANDLE_AUTOCLAMPED.

:HANDLE_AUTO:     
  HANDLE_AUTO.

:HANDLE_ALIGNED:  
  HANDLE_ALIGNED.

:HANDLE_VECTOR:   
  HANDLE_VECTOR.

:HANDLE_FREE:     
  HANDLE_FREE.

:VIEW_PERSPECTIVE:
  VIEW_PERSPECTIVE.

:VIEW_ORTHO:      
  VIEW_ORTHO.

:VIEW_CAMERA:     
  VIEW_CAMERA.

:VIEW_PAN:        
  VIEW_PAN.

:VIEW_ZOOM:       
  VIEW_ZOOM.

:BRUSH_BLOB:      
  BRUSH_BLOB.

:BRUSH_BLUR:      
  BRUSH_BLUR.

:BRUSH_CLAY:      
  BRUSH_CLAY.

:BRUSH_CLAY_STRIPS:
  BRUSH_CLAY_STRIPS.

:BRUSH_CLONE:     
  BRUSH_CLONE.

:BRUSH_CREASE:    
  BRUSH_CREASE.

:BRUSH_FILL:      
  BRUSH_FILL.

:BRUSH_FLATTEN:   
  BRUSH_FLATTEN.

:BRUSH_GRAB:      
  BRUSH_GRAB.

:BRUSH_INFLATE:   
  BRUSH_INFLATE.

:BRUSH_LAYER:     
  BRUSH_LAYER.

:BRUSH_MASK:      
  BRUSH_MASK.

:BRUSH_MIX:       
  BRUSH_MIX.

:BRUSH_NUDGE:     
  BRUSH_NUDGE.

:BRUSH_PAINT_SELECT:
  BRUSH_PAINT_SELECT.

:BRUSH_PINCH:     
  BRUSH_PINCH.

:BRUSH_SCRAPE:    
  BRUSH_SCRAPE.

:BRUSH_SCULPT_DRAW:
  BRUSH_SCULPT_DRAW.

:BRUSH_SMEAR:     
  BRUSH_SMEAR.

:BRUSH_SMOOTH:    
  BRUSH_SMOOTH.

:BRUSH_SNAKE_HOOK:
  BRUSH_SNAKE_HOOK.

:BRUSH_SOFTEN:    
  BRUSH_SOFTEN.

:BRUSH_TEXDRAW:   
  BRUSH_TEXDRAW.

:BRUSH_TEXFILL:   
  BRUSH_TEXFILL.

:BRUSH_TEXMASK:   
  BRUSH_TEXMASK.

:BRUSH_THUMB:     
  BRUSH_THUMB.

:BRUSH_ROTATE:    
  BRUSH_ROTATE.

:GPBRUSH_SMOOTH:  
  GPBRUSH_SMOOTH.

:GPBRUSH_THICKNESS:
  GPBRUSH_THICKNESS.

:GPBRUSH_STRENGTH:
  GPBRUSH_STRENGTH.

:GPBRUSH_GRAB:    
  GPBRUSH_GRAB.

:GPBRUSH_PUSH:    
  GPBRUSH_PUSH.

:GPBRUSH_TWIST:   
  GPBRUSH_TWIST.

:GPBRUSH_PINCH:   
  GPBRUSH_PINCH.

:GPBRUSH_RANDOMIZE:
  GPBRUSH_RANDOMIZE.

:GPBRUSH_CLONE:   
  GPBRUSH_CLONE.

:GPBRUSH_WEIGHT:  
  GPBRUSH_WEIGHT.

:GPBRUSH_PENCIL:  
  GPBRUSH_PENCIL.

:GPBRUSH_PEN:     
  GPBRUSH_PEN.

:GPBRUSH_INK:     
  GPBRUSH_INK.

:GPBRUSH_INKNOISE:
  GPBRUSH_INKNOISE.

:GPBRUSH_BLOCK:   
  GPBRUSH_BLOCK.

:GPBRUSH_MARKER:  
  GPBRUSH_MARKER.

:GPBRUSH_FILL:    
  GPBRUSH_FILL.

:GPBRUSH_AIRBRUSH:
  GPBRUSH_AIRBRUSH.

:GPBRUSH_CHISEL:  
  GPBRUSH_CHISEL.

:GPBRUSH_ERASE_SOFT:
  GPBRUSH_ERASE_SOFT.

:GPBRUSH_ERASE_HARD:
  GPBRUSH_ERASE_HARD.

:GPBRUSH_ERASE_STROKE:
  GPBRUSH_ERASE_STROKE.

:BRUSH_CURVES_ADD:
  BRUSH_CURVES_ADD.

:BRUSH_CURVES_COMB:
  BRUSH_CURVES_COMB.

:BRUSH_CURVES_CUT:
  BRUSH_CURVES_CUT.

:BRUSH_CURVES_DELETE:
  BRUSH_CURVES_DELETE.

:BRUSH_CURVES_DENSITY:
  BRUSH_CURVES_DENSITY.

:BRUSH_CURVES_GROW_SHRINK:
  BRUSH_CURVES_GROW_SHRINK.

:BRUSH_CURVES_PINCH:
  BRUSH_CURVES_PINCH.

:BRUSH_CURVES_PUFF:
  BRUSH_CURVES_PUFF.

:BRUSH_CURVES_SLIDE:
  BRUSH_CURVES_SLIDE.

:BRUSH_CURVES_SMOOTH:
  BRUSH_CURVES_SMOOTH.

:BRUSH_CURVES_SNAKE_HOOK:
  BRUSH_CURVES_SNAKE_HOOK.

:KEYTYPE_KEYFRAME_VEC:
  KEYTYPE_KEYFRAME_VEC.

:KEYTYPE_BREAKDOWN_VEC:
  KEYTYPE_BREAKDOWN_VEC.

:KEYTYPE_EXTREME_VEC:
  KEYTYPE_EXTREME_VEC.

:KEYTYPE_JITTER_VEC:
  KEYTYPE_JITTER_VEC.

:KEYTYPE_MOVING_HOLD_VEC:
  KEYTYPE_MOVING_HOLD_VEC.

:HANDLETYPE_FREE_VEC:
  HANDLETYPE_FREE_VEC.

:HANDLETYPE_ALIGNED_VEC:
  HANDLETYPE_ALIGNED_VEC.

:HANDLETYPE_VECTOR_VEC:
  HANDLETYPE_VECTOR_VEC.

:HANDLETYPE_AUTO_VEC:
  HANDLETYPE_AUTO_VEC.

:HANDLETYPE_AUTO_CLAMP_VEC:
  HANDLETYPE_AUTO_CLAMP_VEC.

:COLORSET_01_VEC: 
  COLORSET_01_VEC.

:COLORSET_02_VEC: 
  COLORSET_02_VEC.

:COLORSET_03_VEC: 
  COLORSET_03_VEC.

:COLORSET_04_VEC: 
  COLORSET_04_VEC.

:COLORSET_05_VEC: 
  COLORSET_05_VEC.

:COLORSET_06_VEC: 
  COLORSET_06_VEC.

:COLORSET_07_VEC: 
  COLORSET_07_VEC.

:COLORSET_08_VEC: 
  COLORSET_08_VEC.

:COLORSET_09_VEC: 
  COLORSET_09_VEC.

:COLORSET_10_VEC: 
  COLORSET_10_VEC.

:COLORSET_11_VEC: 
  COLORSET_11_VEC.

:COLORSET_12_VEC: 
  COLORSET_12_VEC.

:COLORSET_13_VEC: 
  COLORSET_13_VEC.

:COLORSET_14_VEC: 
  COLORSET_14_VEC.

:COLORSET_15_VEC: 
  COLORSET_15_VEC.

:COLORSET_16_VEC: 
  COLORSET_16_VEC.

:COLORSET_17_VEC: 
  COLORSET_17_VEC.

:COLORSET_18_VEC: 
  COLORSET_18_VEC.

:COLORSET_19_VEC: 
  COLORSET_19_VEC.

:COLORSET_20_VEC: 
  COLORSET_20_VEC.

:COLLECTION_COLOR_01:
  COLLECTION_COLOR_01.

:COLLECTION_COLOR_02:
  COLLECTION_COLOR_02.

:COLLECTION_COLOR_03:
  COLLECTION_COLOR_03.

:COLLECTION_COLOR_04:
  COLLECTION_COLOR_04.

:COLLECTION_COLOR_05:
  COLLECTION_COLOR_05.

:COLLECTION_COLOR_06:
  COLLECTION_COLOR_06.

:COLLECTION_COLOR_07:
  COLLECTION_COLOR_07.

:COLLECTION_COLOR_08:
  COLLECTION_COLOR_08.

:SEQUENCE_COLOR_01:
  SEQUENCE_COLOR_01.

:SEQUENCE_COLOR_02:
  SEQUENCE_COLOR_02.

:SEQUENCE_COLOR_03:
  SEQUENCE_COLOR_03.

:SEQUENCE_COLOR_04:
  SEQUENCE_COLOR_04.

:SEQUENCE_COLOR_05:
  SEQUENCE_COLOR_05.

:SEQUENCE_COLOR_06:
  SEQUENCE_COLOR_06.

:SEQUENCE_COLOR_07:
  SEQUENCE_COLOR_07.

:SEQUENCE_COLOR_08:
  SEQUENCE_COLOR_08.

:SEQUENCE_COLOR_09:
  SEQUENCE_COLOR_09.

:LIBRARY_DATA_INDIRECT:
  LIBRARY_DATA_INDIRECT.

:LIBRARY_DATA_OVERRIDE_NONEDITABLE:
  LIBRARY_DATA_OVERRIDE_NONEDITABLE.

:EVENT_A:         
  EVENT_A.

:EVENT_B:         
  EVENT_B.

:EVENT_C:         
  EVENT_C.

:EVENT_D:         
  EVENT_D.

:EVENT_E:         
  EVENT_E.

:EVENT_F:         
  EVENT_F.

:EVENT_G:         
  EVENT_G.

:EVENT_H:         
  EVENT_H.

:EVENT_I:         
  EVENT_I.

:EVENT_J:         
  EVENT_J.

:EVENT_K:         
  EVENT_K.

:EVENT_L:         
  EVENT_L.

:EVENT_M:         
  EVENT_M.

:EVENT_N:         
  EVENT_N.

:EVENT_O:         
  EVENT_O.

:EVENT_P:         
  EVENT_P.

:EVENT_Q:         
  EVENT_Q.

:EVENT_R:         
  EVENT_R.

:EVENT_S:         
  EVENT_S.

:EVENT_T:         
  EVENT_T.

:EVENT_U:         
  EVENT_U.

:EVENT_V:         
  EVENT_V.

:EVENT_W:         
  EVENT_W.

:EVENT_X:         
  EVENT_X.

:EVENT_Y:         
  EVENT_Y.

:EVENT_Z:         
  EVENT_Z.

:EVENT_SHIFT:     
  EVENT_SHIFT.

:EVENT_CTRL:      
  EVENT_CTRL.

:EVENT_ALT:       
  EVENT_ALT.

:EVENT_OS:        
  EVENT_OS.

:EVENT_F1:        
  EVENT_F1.

:EVENT_F2:        
  EVENT_F2.

:EVENT_F3:        
  EVENT_F3.

:EVENT_F4:        
  EVENT_F4.

:EVENT_F5:        
  EVENT_F5.

:EVENT_F6:        
  EVENT_F6.

:EVENT_F7:        
  EVENT_F7.

:EVENT_F8:        
  EVENT_F8.

:EVENT_F9:        
  EVENT_F9.

:EVENT_F10:       
  EVENT_F10.

:EVENT_F11:       
  EVENT_F11.

:EVENT_F12:       
  EVENT_F12.

:EVENT_ESC:       
  EVENT_ESC.

:EVENT_TAB:       
  EVENT_TAB.

:EVENT_PAGEUP:    
  EVENT_PAGEUP.

:EVENT_PAGEDOWN:  
  EVENT_PAGEDOWN.

:EVENT_RETURN:    
  EVENT_RETURN.

:EVENT_SPACEKEY:  
  EVENT_SPACEKEY.

.. _rna-enum-icon-items:

"""

import typing



"""


Curve Operators
***************

:func:`cyclic_toggle`

:func:`de_select_first`

:func:`de_select_last`

:func:`decimate`

:func:`delete`

:func:`dissolve_verts`

:func:`draw`

:func:`duplicate`

:func:`duplicate_move`

:func:`extrude`

:func:`extrude_move`

:func:`handle_type_set`

:func:`hide`

:func:`make_segment`

:func:`match_texture_space`

:func:`normals_make_consistent`

:func:`pen`

:func:`primitive_bezier_circle_add`

:func:`primitive_bezier_curve_add`

:func:`primitive_nurbs_circle_add`

:func:`primitive_nurbs_curve_add`

:func:`primitive_nurbs_path_add`

:func:`radius_set`

:func:`reveal`

:func:`select_all`

:func:`select_less`

:func:`select_linked`

:func:`select_linked_pick`

:func:`select_more`

:func:`select_next`

:func:`select_nth`

:func:`select_previous`

:func:`select_random`

:func:`select_row`

:func:`select_similar`

:func:`separate`

:func:`shade_flat`

:func:`shade_smooth`

:func:`shortest_path_pick`

:func:`smooth`

:func:`smooth_radius`

:func:`smooth_tilt`

:func:`smooth_weight`

:func:`spin`

:func:`spline_type_set`

:func:`spline_weight_set`

:func:`split`

:func:`subdivide`

:func:`switch_direction`

:func:`tilt_clear`

:func:`vertex_add`

"""

import typing

import mathutils

def cyclic_toggle(direction: str = 'CYCLIC_U') -> None:

  """

  Make active spline closed/opened loop

  """

  ...

def de_select_first() -> None:

  """

  (De)select first of visible part of each NURBS

  """

  ...

def de_select_last() -> None:

  """

  (De)select last of visible part of each NURBS

  """

  ...

def decimate(ratio: float = 1.0) -> None:

  """

  Simplify selected curves

  """

  ...

def delete(type: str = 'VERT') -> None:

  """

  Delete selected control points or segments

  """

  ...

def dissolve_verts() -> None:

  """

  Delete selected control points, correcting surrounding handles

  """

  ...

def draw(error_threshold: float = 0.0, fit_method: str = 'REFIT', corner_angle: float = 1.22173, use_cyclic: bool = True, stroke: typing.Union[typing.Sequence[OperatorStrokeElement], typing.Mapping[str, OperatorStrokeElement], bpy.types.bpy_prop_collection] = None, wait_for_input: bool = True) -> None:

  """

  Draw a freehand spline

  """

  ...

def duplicate() -> None:

  """

  Duplicate selected control points

  """

  ...

def duplicate_move(CURVE_OT_duplicate: CURVE_OT_duplicate = None, TRANSFORM_OT_translate: TRANSFORM_OT_translate = None) -> None:

  """

  Duplicate curve and move

  """

  ...

def extrude(mode: str = 'TRANSLATION') -> None:

  """

  Extrude selected control point(s)

  """

  ...

def extrude_move(CURVE_OT_extrude: CURVE_OT_extrude = None, TRANSFORM_OT_translate: TRANSFORM_OT_translate = None) -> None:

  """

  Extrude curve and move result

  """

  ...

def handle_type_set(type: str = 'AUTOMATIC') -> None:

  """

  Set type of handles for selected control points

  """

  ...

def hide(unselected: bool = False) -> None:

  """

  Hide (un)selected control points

  """

  ...

def make_segment() -> None:

  """

  Join two curves by their selected ends

  """

  ...

def match_texture_space() -> None:

  """

  Match texture space to object's bounding box

  """

  ...

def normals_make_consistent(calc_length: bool = False) -> None:

  """

  Recalculate the direction of selected handles

  """

  ...

def pen(extend: bool = False, deselect: bool = False, toggle: bool = False, deselect_all: bool = False, select_passthrough: bool = False, extrude_point: bool = False, extrude_handle: str = 'VECTOR', delete_point: bool = False, insert_point: bool = False, move_segment: bool = False, select_point: bool = False, move_point: bool = False, close_spline: bool = True, close_spline_method: str = 'OFF', toggle_vector: bool = False, cycle_handle_type: bool = False) -> None:

  """

  Construct and edit splines

  """

  ...

def primitive_bezier_circle_add(radius: float = 1.0, enter_editmode: bool = False, align: str = 'WORLD', location: mathutils.Vector = (0.0, 0.0, 0.0), rotation: mathutils.Euler = (0.0, 0.0, 0.0), scale: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Construct a Bezier Circle

  """

  ...

def primitive_bezier_curve_add(radius: float = 1.0, enter_editmode: bool = False, align: str = 'WORLD', location: mathutils.Vector = (0.0, 0.0, 0.0), rotation: mathutils.Euler = (0.0, 0.0, 0.0), scale: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Construct a Bezier Curve

  """

  ...

def primitive_nurbs_circle_add(radius: float = 1.0, enter_editmode: bool = False, align: str = 'WORLD', location: mathutils.Vector = (0.0, 0.0, 0.0), rotation: mathutils.Euler = (0.0, 0.0, 0.0), scale: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Construct a Nurbs Circle

  """

  ...

def primitive_nurbs_curve_add(radius: float = 1.0, enter_editmode: bool = False, align: str = 'WORLD', location: mathutils.Vector = (0.0, 0.0, 0.0), rotation: mathutils.Euler = (0.0, 0.0, 0.0), scale: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Construct a Nurbs Curve

  """

  ...

def primitive_nurbs_path_add(radius: float = 1.0, enter_editmode: bool = False, align: str = 'WORLD', location: mathutils.Vector = (0.0, 0.0, 0.0), rotation: mathutils.Euler = (0.0, 0.0, 0.0), scale: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Construct a Path

  """

  ...

def radius_set(radius: float = 1.0) -> None:

  """

  Set per-point radius which is used for bevel tapering

  """

  ...

def reveal(select: bool = True) -> None:

  """

  Reveal hidden control points

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  (De)select all control points

  """

  ...

def select_less() -> None:

  """

  Deselect control points at the boundary of each selection region

  """

  ...

def select_linked() -> None:

  """

  Select all control points linked to the current selection

  """

  ...

def select_linked_pick(deselect: bool = False) -> None:

  """

  Select all control points linked to already selected ones

  """

  ...

def select_more() -> None:

  """

  Select control points at the boundary of each selection region

  """

  ...

def select_next() -> None:

  """

  Select control points following already selected ones along the curves

  """

  ...

def select_nth(skip: int = 1, nth: int = 1, offset: int = 0) -> None:

  """

  Deselect every Nth point starting from the active one

  """

  ...

def select_previous() -> None:

  """

  Select control points preceding already selected ones along the curves

  """

  ...

def select_random(ratio: float = 0.5, seed: int = 0, action: str = 'SELECT') -> None:

  """

  Randomly select some control points

  """

  ...

def select_row() -> None:

  """

  Select a row of control points including active one

  """

  ...

def select_similar(type: str = 'WEIGHT', compare: str = 'EQUAL', threshold: float = 0.1) -> None:

  """

  Select similar curve points by property type

  """

  ...

def separate(confirm: bool = True) -> None:

  """

  Separate selected points from connected unselected points into a new object

  """

  ...

def shade_flat() -> None:

  """

  Set shading to flat

  """

  ...

def shade_smooth() -> None:

  """

  Set shading to smooth

  """

  ...

def shortest_path_pick() -> None:

  """

  Select shortest path between two selections

  """

  ...

def smooth() -> None:

  """

  Flatten angles of selected points

  """

  ...

def smooth_radius() -> None:

  """

  Interpolate radii of selected points

  """

  ...

def smooth_tilt() -> None:

  """

  Interpolate tilt of selected points

  """

  ...

def smooth_weight() -> None:

  """

  Interpolate weight of selected points

  """

  ...

def spin(center: mathutils.Vector = (0.0, 0.0, 0.0), axis: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Extrude selected boundary row around pivot point and current view axis

  """

  ...

def spline_type_set(type: str = 'POLY', use_handles: bool = False) -> None:

  """

  Set type of active spline

  """

  ...

def spline_weight_set(weight: float = 1.0) -> None:

  """

  Set softbody goal weight for selected points

  """

  ...

def split() -> None:

  """

  Split off selected points from connected unselected points

  """

  ...

def subdivide(number_cuts: int = 1) -> None:

  """

  Subdivide selected segments

  """

  ...

def switch_direction() -> None:

  """

  Switch direction of selected splines

  """

  ...

def tilt_clear() -> None:

  """

  Clear the tilt of selected control points

  """

  ...

def vertex_add(location: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Add a new control point (linked to only selected end-curve one, if any)

  """

  ...



"""


Node Socket Type Items
^^^^^^^^^^^^^^^^^^^^^^

:CUSTOM:          
  Custom.

:VALUE:           
  Value.

:INT:             
  Integer.

:BOOLEAN:         
  Boolean.

:VECTOR:          
  Vector.

:ROTATION:        
  Rotation.

:STRING:          
  String.

:RGBA:            
  RGBA.

:SHADER:          
  Shader.

:OBJECT:          
  Object.

:IMAGE:           
  Image.

:GEOMETRY:        
  Geometry.

:COLLECTION:      
  Collection.

:TEXTURE:         
  Texture.

:MATERIAL:        
  Material.

.. _rna-enum-node-socket-type-items:

"""

import typing



"""


Object Shaderfx Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:FX_BLUR:         
  Blur.

  Apply Gaussian Blur to object.

:FX_COLORIZE:     
  Colorize.

  Apply different tint effects.

:FX_FLIP:         
  Flip.

  Flip image.

:FX_GLOW:         
  Glow.

  Create a glow effect.

:FX_PIXEL:        
  Pixelate.

  Pixelate image.

:FX_RIM:          
  Rim.

  Add a rim to the image.

:FX_SHADOW:       
  Shadow.

  Create a shadow effect.

:FX_SWIRL:        
  Swirl.

  Create a rotation distortion.

:FX_WAVE:         
  Wave Distortion.

  Apply sinusoidal deformation.

.. _rna-enum-object-shaderfx-type-items:

"""

import typing



"""


Operator Return Items
^^^^^^^^^^^^^^^^^^^^^

:RUNNING_MODAL:   
  Running Modal.

  Keep the operator running with blender.

:CANCELLED:       
  Cancelled.

  The operator exited without doing anything, so no undo entry should be pushed.

:FINISHED:        
  Finished.

  The operator exited after completing its action.

:PASS_THROUGH:    
  Pass Through.

  Do nothing and pass the event on.

:INTERFACE:       
  Interface.

  Handled but not executed (popup menus).

.. _rna-enum-operator-return-items:

"""

import typing



"""


Dt Mix Mode Items
^^^^^^^^^^^^^^^^^

:REPLACE:         
  Replace.

  Overwrite all elements' data.

:ABOVE_THRESHOLD: 
  Above Threshold.

  Only replace destination elements where data is above given threshold (exact behavior depends on data type).

:BELOW_THRESHOLD: 
  Below Threshold.

  Only replace destination elements where data is below given threshold (exact behavior depends on data type).

:MIX:             
  Mix.

  Mix source value into destination one, using given threshold as factor.

:ADD:             
  Add.

  Add source value to destination one, using given threshold as factor.

:SUB:             
  Subtract.

  Subtract source value to destination one, using given threshold as factor.

:MUL:             
  Multiply.

  Multiply source value to destination one, using given threshold as factor.

.. _rna-enum-dt-mix-mode-items:

"""

import typing



"""


BVHTree Utilities (mathutils.bvhtree)
*************************************

BVH tree structures for proximity searches and ray casts on geometry.

:class:`BVHTree`

"""

import typing

class BVHTree:

  @classmethod

  def FromBMesh(cls, bmesh: BMesh, epsilon: float = 0.0) -> None:

    """

    BVH tree based on :class:`BMesh` data.

    """

    ...

  @classmethod

  def FromObject(cls, object: Object, depsgraph: Depsgraph, deform: bool = True, render: typing.Any = False, cage: bool = False, epsilon: float = 0.0) -> None:

    """

    BVH tree based on :class:`Object` data.

    """

    ...

  @classmethod

  def FromPolygons(cls, vertices: float, polygons: typing.Sequence[typing.Any], all_triangles: bool = False, epsilon: float = 0.0) -> None:

    """

    BVH tree constructed geometry passed in as arguments.

    """

    ...

  def find_nearest(self, origin: typing.Any, distance: float = 1.84467e+19) -> tuple:

    """

    Find the nearest element (typically face index) to a point.

    """

    ...

  def find_nearest_range(self, origin: typing.Any, distance: float = 1.84467e+19) -> list:

    """

    Find the nearest elements (typically face index) to a point in the distance range.

    """

    ...

  def overlap(self, other_tree: BVHTree) -> list:

    """

    Find overlapping indices between 2 trees.

    """

    ...

  def ray_cast(self, origin: Vector, direction: Vector, distance: float = sys.float_info.max) -> tuple:

    """

    Cast a ray onto the mesh.

    """

    ...



"""


Graph Operators
***************

:func:`bake`

:func:`blend_to_default`

:func:`blend_to_neighbor`

:func:`breakdown`

:func:`butterworth_smooth`

:func:`clean`

:func:`click_insert`

:func:`clickselect`

:func:`copy`

:func:`cursor_set`

:func:`decimate`

:func:`delete`

:func:`driver_delete_invalid`

:func:`driver_variables_copy`

:func:`driver_variables_paste`

:func:`duplicate`

:func:`duplicate_move`

:func:`ease`

:func:`easing_type`

:func:`equalize_handles`

:func:`euler_filter`

:func:`extrapolation_type`

:func:`fmodifier_add`

:func:`fmodifier_copy`

:func:`fmodifier_paste`

:func:`frame_jump`

:func:`gaussian_smooth`

:func:`ghost_curves_clear`

:func:`ghost_curves_create`

:func:`handle_type`

:func:`hide`

:func:`interpolation_type`

:func:`keyframe_insert`

:func:`keyframe_jump`

:func:`mirror`

:func:`paste`

:func:`previewrange_set`

:func:`reveal`

:func:`sample`

:func:`select_all`

:func:`select_box`

:func:`select_circle`

:func:`select_column`

:func:`select_lasso`

:func:`select_leftright`

:func:`select_less`

:func:`select_linked`

:func:`select_more`

:func:`smooth`

:func:`snap`

:func:`snap_cursor_value`

:func:`sound_bake`

:func:`unbake`

:func:`view_all`

:func:`view_frame`

:func:`view_selected`

"""

import typing

def bake(confirm: bool = True) -> None:

  """

  Bake selected F-Curves to a set of sampled points defining a similar curve

  """

  ...

def blend_to_default(factor: float = 0.0) -> None:

  """

  Blend selected keys to their default value from their current position

  """

  ...

def blend_to_neighbor(factor: float = 0.0) -> None:

  """

  Blend selected keyframes to their left or right neighbor

  """

  ...

def breakdown(factor: float = 0.0) -> None:

  """

  Move selected keyframes to an inbetween position relative to adjacent keys

  """

  ...

def butterworth_smooth(cutoff_frequency: float = 3.0, filter_order: int = 4, samples_per_frame: int = 1, blend: float = 1.0, blend_in_out: int = 1) -> None:

  """

  Smooth an F-Curve while maintaining the general shape of the curve

  """

  ...

def clean(threshold: float = 0.001, channels: bool = False) -> None:

  """

  Simplify F-Curves by removing closely spaced keyframes

  """

  ...

def click_insert(frame: float = 1.0, value: float = 1.0, extend: bool = False) -> None:

  """

  Insert new keyframe at the cursor position for the active F-Curve

  """

  ...

def clickselect(wait_to_deselect_others: bool = False, mouse_x: int = 0, mouse_y: int = 0, extend: bool = False, deselect_all: bool = False, column: bool = False, curves: bool = False) -> None:

  """

  Select keyframes by clicking on them

  """

  ...

def copy() -> None:

  """

  Copy selected keyframes to the internal clipboard

  """

  ...

def cursor_set(frame: float = 0.0, value: float = 0.0) -> None:

  """

  Interactively set the current frame and value cursor

  """

  ...

def decimate(mode: str = 'RATIO', factor: float = 0.333333, remove_error_margin: float = 0.0) -> None:

  """

  Decimate F-Curves by removing keyframes that influence the curve shape the least

  """

  ...

def delete(confirm: bool = True) -> None:

  """

  Remove all selected keyframes

  """

  ...

def driver_delete_invalid() -> None:

  """

  Delete all visible drivers considered invalid

  """

  ...

def driver_variables_copy() -> None:

  """

  Copy the driver variables of the active driver

  """

  ...

def driver_variables_paste(replace: bool = False) -> None:

  """

  Add copied driver variables to the active driver

  """

  ...

def duplicate(mode: str = 'TRANSLATION') -> None:

  """

  Make a copy of all selected keyframes

  """

  ...

def duplicate_move(GRAPH_OT_duplicate: GRAPH_OT_duplicate = None, TRANSFORM_OT_translate: TRANSFORM_OT_translate = None) -> None:

  """

  Make a copy of all selected keyframes and move them

  """

  ...

def ease(factor: float = 0.0) -> None:

  """

  Align keyframes on a ease-in or ease-out curve

  """

  ...

def easing_type(type: str = 'AUTO') -> None:

  """

  Set easing type for the F-Curve segments starting from the selected keyframes

  """

  ...

def equalize_handles(side: str = 'LEFT', handle_length: float = 5.0, flatten: bool = False) -> None:

  """

  Ensure selected keyframes' handles have equal length, optionally making them horizontal. Automatic, Automatic Clamped, or Vector handle types will be converted to Aligned

  """

  ...

def euler_filter() -> None:

  """

  Fix large jumps and flips in the selected Euler Rotation F-Curves arising from rotation values being clipped when baking physics

  """

  ...

def extrapolation_type(type: str = 'CONSTANT') -> None:

  """

  Set extrapolation mode for selected F-Curves

  """

  ...

def fmodifier_add(type: str = 'nullptr', only_active: bool = False) -> None:

  """

  Add F-Modifier to the active/selected F-Curves

  """

  ...

def fmodifier_copy() -> None:

  """

  Copy the F-Modifier(s) of the active F-Curve

  """

  ...

def fmodifier_paste(only_active: bool = False, replace: bool = False) -> None:

  """

  Add copied F-Modifiers to the selected F-Curves

  """

  ...

def frame_jump() -> None:

  """

  Place the cursor on the midpoint of selected keyframes

  """

  ...

def gaussian_smooth(factor: float = 1.0, sigma: float = 0.33, filter_width: int = 6) -> None:

  """

  Smooth the curve using a Gaussian filter

  """

  ...

def ghost_curves_clear() -> None:

  """

  Clear F-Curve snapshots (Ghosts) for active Graph Editor

  """

  ...

def ghost_curves_create() -> None:

  """

  Create snapshot (Ghosts) of selected F-Curves as background aid for active Graph Editor

  """

  ...

def handle_type(type: str = 'FREE') -> None:

  """

  Set type of handle for selected keyframes

  """

  ...

def hide(unselected: bool = False) -> None:

  """

  Hide selected curves from Graph Editor view

  """

  ...

def interpolation_type(type: str = 'CONSTANT') -> None:

  """

  Set interpolation mode for the F-Curve segments starting from the selected keyframes

  """

  ...

def keyframe_insert(type: str = 'ALL') -> None:

  """

  Insert keyframes for the specified channels

  """

  ...

def keyframe_jump(next: bool = True) -> None:

  """

  Jump to previous/next keyframe

  """

  ...

def mirror(type: str = 'CFRA') -> None:

  """

  Flip selected keyframes over the selected mirror line

  """

  ...

def paste(offset: str = 'START', value_offset: str = 'NONE', merge: str = 'MIX', flipped: bool = False) -> None:

  """

  Paste keyframes from the internal clipboard for the selected channels, starting on the current frame

  """

  ...

def previewrange_set() -> None:

  """

  Set Preview Range based on range of selected keyframes

  """

  ...

def reveal(select: bool = True) -> None:

  """

  Make previously hidden curves visible again in Graph Editor view

  """

  ...

def sample() -> None:

  """

  Add keyframes on every frame between the selected keyframes

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  Toggle selection of all keyframes

  """

  ...

def select_box(axis_range: bool = False, include_handles: bool = True, tweak: bool = False, use_curve_selection: bool = True, xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Select all keyframes within the specified region

  """

  ...

def select_circle(x: int = 0, y: int = 0, radius: int = 25, wait_for_input: bool = True, mode: str = 'SET', use_curve_selection: bool = True) -> None:

  """

  Select keyframe points using circle selection

  """

  ...

def select_column(mode: str = 'KEYS') -> None:

  """

  Select all keyframes on the specified frame(s)

  """

  ...

def select_lasso(path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None, mode: str = 'SET', use_curve_selection: bool = True) -> None:

  """

  Select keyframe points using lasso selection

  """

  ...

def select_leftright(mode: str = 'CHECK', extend: bool = False) -> None:

  """

  Select keyframes to the left or the right of the current frame

  """

  ...

def select_less() -> None:

  """

  Deselect keyframes on ends of selection islands

  """

  ...

def select_linked() -> None:

  """

  Select keyframes occurring in the same F-Curves as selected ones

  """

  ...

def select_more() -> None:

  """

  Select keyframes beside already selected ones

  """

  ...

def smooth() -> None:

  """

  Apply weighted moving means to make selected F-Curves less bumpy

  """

  ...

def snap(type: str = 'CFRA') -> None:

  """

  Snap selected keyframes to the chosen times/values

  """

  ...

def snap_cursor_value() -> None:

  """

  Place the cursor value on the average value of selected keyframes

  """

  ...

def sound_bake(filepath: str = '', check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = True, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = True, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, show_multiview: bool = False, use_multiview: bool = False, display_type: str = 'DEFAULT', sort_method: str = '', low: float = 0.0, high: float = 100000.0, attack: float = 0.005, release: float = 0.2, threshold: float = 0.0, use_accumulate: bool = False, use_additive: bool = False, use_square: bool = False, sthreshold: float = 0.1) -> None:

  """

  Bakes a sound wave to selected F-Curves

  """

  ...

def unbake() -> None:

  """

  Un-Bake selected F-Points to F-Curves

  """

  ...

def view_all(include_handles: bool = True) -> None:

  """

  Reset viewable area to show full keyframe range

  """

  ...

def view_frame() -> None:

  """

  Move the view to the current frame

  """

  ...

def view_selected(include_handles: bool = True) -> None:

  """

  Reset viewable area to show selected keyframe range

  """

  ...



"""


Brush Sculpt Tool Items
^^^^^^^^^^^^^^^^^^^^^^^

:DRAW:            
  Draw.

:DRAW_SHARP:      
  Draw Sharp.

:CLAY:            
  Clay.

:CLAY_STRIPS:     
  Clay Strips.

:CLAY_THUMB:      
  Clay Thumb.

:LAYER:           
  Layer.

:INFLATE:         
  Inflate.

:BLOB:            
  Blob.

:CREASE:          
  Crease.

.. _rna-enum-brush-sculpt-tool-items:

======================================================================

:SMOOTH:          
  Smooth.

:FLATTEN:         
  Flatten.

:FILL:            
  Fill.

:SCRAPE:          
  Scrape.

:MULTIPLANE_SCRAPE:
  Multi-plane Scrape.

:PINCH:           
  Pinch.

======================================================================

:GRAB:            
  Grab.

:ELASTIC_DEFORM:  
  Elastic Deform.

:SNAKE_HOOK:      
  Snake Hook.

:THUMB:           
  Thumb.

:POSE:            
  Pose.

:NUDGE:           
  Nudge.

:ROTATE:          
  Rotate.

:TOPOLOGY:        
  Slide Relax.

:BOUNDARY:        
  Boundary.

======================================================================

:CLOTH:           
  Cloth.

:SIMPLIFY:        
  Simplify.

:MASK:            
  Mask.

:DRAW_FACE_SETS:  
  Draw Face Sets.

:DISPLACEMENT_ERASER:
  Multires Displacement Eraser.

:DISPLACEMENT_SMEAR:
  Multires Displacement Smear.

:PAINT:           
  Paint.

:SMEAR:           
  Smear.

"""

import typing



"""


Grease Pencil Operators
***********************

:func:`brush_stroke`

:func:`draw_mode_toggle`

:func:`insert_blank_frame`

:func:`layer_add`

:func:`layer_group_add`

:func:`layer_remove`

:func:`layer_reorder`

:func:`select_all`

:func:`select_alternate`

:func:`select_ends`

:func:`select_less`

:func:`select_linked`

:func:`select_more`

:func:`select_random`

:func:`set_selection_mode`

:func:`stroke_simplify`

:func:`stroke_smooth`

"""

import typing

def brush_stroke(stroke: typing.Union[typing.Sequence[OperatorStrokeElement], typing.Mapping[str, OperatorStrokeElement], bpy.types.bpy_prop_collection] = None, mode: str = 'NORMAL') -> None:

  """

  Draw a new stroke in the active Grease Pencil object

  """

  ...

def draw_mode_toggle() -> None:

  """

  Enter/Exit draw mode for grease pencil

  """

  ...

def insert_blank_frame(all_layers: bool = False, duration: int = 1) -> None:

  """

  Insert a blank frame on the current scene frame

  """

  ...

def layer_add(new_layer_name: str = 'GP_Layer') -> None:

  """

  Add a new Grease Pencil layer in the active object

  """

  ...

def layer_group_add(new_layer_group_name: str = 'GP_Group') -> None:

  """

  Add a new Grease Pencil layer group in the active object

  """

  ...

def layer_remove() -> None:

  """

  Remove the active Grease Pencil layer

  """

  ...

def layer_reorder(target_layer_name: str = 'GP_Layer', location: str = 'ABOVE') -> None:

  """

  Reorder the active Grease Pencil layer

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  (De)select all visible strokes

  """

  ...

def select_alternate(deselect_ends: bool = False) -> None:

  """

  Select alternated points in strokes with already selected points

  """

  ...

def select_ends(amount_start: int = 0, amount_end: int = 1) -> None:

  """

  Select end points of strokes

  """

  ...

def select_less() -> None:

  """

  Shrink the selection by one point

  """

  ...

def select_linked() -> None:

  """

  Select all points in curves with any point selection

  """

  ...

def select_more() -> None:

  """

  Grow the selection by one point

  """

  ...

def select_random(ratio: float = 0.5, seed: int = 0, action: str = 'SELECT') -> None:

  """

  Selects random points from the current strokes selection

  """

  ...

def set_selection_mode(mode: str = 'POINT') -> None:

  """

  Change the selection mode for Grease Pencil strokes

  """

  ...

def stroke_simplify(factor: float = 0.001) -> None:

  """

  Simplify selected strokes

  """

  ...

def stroke_smooth(iterations: int = 10, factor: float = 1.0, smooth_ends: bool = False, keep_shape: bool = False, smooth_position: bool = True, smooth_radius: bool = True, smooth_opacity: bool = False) -> None:

  """

  Smooth selected strokes

  """

  ...



"""


Operator Context Items
^^^^^^^^^^^^^^^^^^^^^^

:INVOKE_DEFAULT:  
  Invoke Default.

:INVOKE_REGION_WIN:
  Invoke Region Window.

:INVOKE_REGION_CHANNELS:
  Invoke Region Channels.

:INVOKE_REGION_PREVIEW:
  Invoke Region Preview.

:INVOKE_AREA:     
  Invoke Area.

:INVOKE_SCREEN:   
  Invoke Screen.

:EXEC_DEFAULT:    
  Exec Default.

:EXEC_REGION_WIN: 
  Exec Region Window.

:EXEC_REGION_CHANNELS:
  Exec Region Channels.

:EXEC_REGION_PREVIEW:
  Exec Region Preview.

:EXEC_AREA:       
  Exec Area.

:EXEC_SCREEN:     
  Exec Screen.

.. _rna-enum-operator-context-items:

"""

import typing



"""


Attribute Domain Only Mesh Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:POINT:           
  Point.

  Attribute on point.

:EDGE:            
  Edge.

  Attribute on mesh edge.

:FACE:            
  Face.

  Attribute on mesh faces.

:CORNER:          
  Face Corner.

  Attribute on mesh face corner.

.. _rna-enum-attribute-domain-only-mesh-items:

"""

import typing



"""


Keyframe Handle Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:FREE:            
  Free.

  Completely independent manually set handle.

:ALIGNED:         
  Aligned.

  Manually set handle with rotation locked together with its pair.

:VECTOR:          
  Vector.

  Automatic handles that create straight lines.

:AUTO:            
  Automatic.

  Automatic handles that create smooth curves.

:AUTO_CLAMPED:    
  Auto Clamped.

  Automatic handles that create smooth curves which only change direction at keyframes.

.. _rna-enum-keyframe-handle-type-items:

"""

import typing



"""


Transform Pivot Items Full
^^^^^^^^^^^^^^^^^^^^^^^^^^

:BOUNDING_BOX_CENTER:
  Bounding Box Center.

  Pivot around bounding box center of selected object(s).

:CURSOR:          
  3D Cursor.

  Pivot around the 3D cursor.

:INDIVIDUAL_ORIGINS:
  Individual Origins.

  Pivot around each object's own origin.

:MEDIAN_POINT:    
  Median Point.

  Pivot around the median point of selected objects.

:ACTIVE_ELEMENT:  
  Active Element.

  Pivot around active object.

.. _rna-enum-transform-pivot-items-full:

"""

import typing



"""


Audio System (aud)
******************

Audaspace (pronounced "outer space") is a high level audio library.


Basic Sound Playback
====================

This script shows how to use the classes: :class:`Device`, :class:`Sound` and
:class:`Handle`.

.. code::

  import aud

  device = aud.Device()
  # load sound file (it can be a video file with audio)
  sound = aud.Sound('music.ogg')

  # play the audio, this return a handle to control play/pause
  handle = device.play(sound)
  # if the audio is not too big and will be used often you can buffer it
  sound_buffered = aud.Sound.cache(sound)
  handle_buffered = device.play(sound_buffered)

  # stop the sounds (otherwise they play until their ends)
  handle.stop()
  handle_buffered.stop()

:data:`AP_LOCATION`

:data:`AP_ORIENTATION`

:data:`AP_PANNING`

:data:`AP_PITCH`

:data:`AP_VOLUME`

:data:`CHANNELS_INVALID`

:data:`CHANNELS_MONO`

:data:`CHANNELS_STEREO`

:data:`CHANNELS_STEREO_LFE`

:data:`CHANNELS_SURROUND4`

:data:`CHANNELS_SURROUND5`

:data:`CHANNELS_SURROUND51`

:data:`CHANNELS_SURROUND61`

:data:`CHANNELS_SURROUND71`

:data:`CODEC_AAC`

:data:`CODEC_AC3`

:data:`CODEC_FLAC`

:data:`CODEC_INVALID`

:data:`CODEC_MP2`

:data:`CODEC_MP3`

:data:`CODEC_OPUS`

:data:`CODEC_PCM`

:data:`CODEC_VORBIS`

:data:`CONTAINER_AC3`

:data:`CONTAINER_FLAC`

:data:`CONTAINER_INVALID`

:data:`CONTAINER_MATROSKA`

:data:`CONTAINER_MP2`

:data:`CONTAINER_MP3`

:data:`CONTAINER_OGG`

:data:`CONTAINER_WAV`

:data:`DISTANCE_MODEL_EXPONENT`

:data:`DISTANCE_MODEL_EXPONENT_CLAMPED`

:data:`DISTANCE_MODEL_INVALID`

:data:`DISTANCE_MODEL_INVERSE`

:data:`DISTANCE_MODEL_INVERSE_CLAMPED`

:data:`DISTANCE_MODEL_LINEAR`

:data:`DISTANCE_MODEL_LINEAR_CLAMPED`

:data:`FORMAT_FLOAT32`

:data:`FORMAT_FLOAT64`

:data:`FORMAT_INVALID`

:data:`FORMAT_S16`

:data:`FORMAT_S24`

:data:`FORMAT_S32`

:data:`FORMAT_U8`

:data:`RATE_11025`

:data:`RATE_16000`

:data:`RATE_192000`

:data:`RATE_22050`

:data:`RATE_32000`

:data:`RATE_44100`

:data:`RATE_48000`

:data:`RATE_8000`

:data:`RATE_88200`

:data:`RATE_96000`

:data:`RATE_INVALID`

:data:`STATUS_INVALID`

:data:`STATUS_PAUSED`

:data:`STATUS_PLAYING`

:data:`STATUS_STOPPED`

:class:`Device`

:class:`DynamicMusic`

:class:`Handle`

:class:`PlaybackManager`

:class:`Sequence`

:class:`SequenceEntry`

:class:`Sound`

:class:`Source`

:class:`ThreadPool`

:class:`error`

"""

import typing

import numpy

AP_LOCATION: typing.Any = ...

"""

Constant value 3

"""

AP_ORIENTATION: typing.Any = ...

"""

Constant value 4

"""

AP_PANNING: typing.Any = ...

"""

Constant value 1

"""

AP_PITCH: typing.Any = ...

"""

Constant value 2

"""

AP_VOLUME: typing.Any = ...

"""

Constant value 0

"""

CHANNELS_INVALID: typing.Any = ...

"""

Constant value 0

"""

CHANNELS_MONO: typing.Any = ...

"""

Constant value 1

"""

CHANNELS_STEREO: typing.Any = ...

"""

Constant value 2

"""

CHANNELS_STEREO_LFE: typing.Any = ...

"""

Constant value 3

"""

CHANNELS_SURROUND4: typing.Any = ...

"""

Constant value 4

"""

CHANNELS_SURROUND5: typing.Any = ...

"""

Constant value 5

"""

CHANNELS_SURROUND51: typing.Any = ...

"""

Constant value 6

"""

CHANNELS_SURROUND61: typing.Any = ...

"""

Constant value 7

"""

CHANNELS_SURROUND71: typing.Any = ...

"""

Constant value 8

"""

CODEC_AAC: typing.Any = ...

"""

Constant value 1

"""

CODEC_AC3: typing.Any = ...

"""

Constant value 2

"""

CODEC_FLAC: typing.Any = ...

"""

Constant value 3

"""

CODEC_INVALID: typing.Any = ...

"""

Constant value 0

"""

CODEC_MP2: typing.Any = ...

"""

Constant value 4

"""

CODEC_MP3: typing.Any = ...

"""

Constant value 5

"""

CODEC_OPUS: typing.Any = ...

"""

Constant value 8

"""

CODEC_PCM: typing.Any = ...

"""

Constant value 6

"""

CODEC_VORBIS: typing.Any = ...

"""

Constant value 7

"""

CONTAINER_AC3: typing.Any = ...

"""

Constant value 1

"""

CONTAINER_FLAC: typing.Any = ...

"""

Constant value 2

"""

CONTAINER_INVALID: typing.Any = ...

"""

Constant value 0

"""

CONTAINER_MATROSKA: typing.Any = ...

"""

Constant value 3

"""

CONTAINER_MP2: typing.Any = ...

"""

Constant value 4

"""

CONTAINER_MP3: typing.Any = ...

"""

Constant value 5

"""

CONTAINER_OGG: typing.Any = ...

"""

Constant value 6

"""

CONTAINER_WAV: typing.Any = ...

"""

Constant value 7

"""

DISTANCE_MODEL_EXPONENT: typing.Any = ...

"""

Constant value 5

"""

DISTANCE_MODEL_EXPONENT_CLAMPED: typing.Any = ...

"""

Constant value 6

"""

DISTANCE_MODEL_INVALID: typing.Any = ...

"""

Constant value 0

"""

DISTANCE_MODEL_INVERSE: typing.Any = ...

"""

Constant value 1

"""

DISTANCE_MODEL_INVERSE_CLAMPED: typing.Any = ...

"""

Constant value 2

"""

DISTANCE_MODEL_LINEAR: typing.Any = ...

"""

Constant value 3

"""

DISTANCE_MODEL_LINEAR_CLAMPED: typing.Any = ...

"""

Constant value 4

"""

FORMAT_FLOAT32: typing.Any = ...

"""

Constant value 36

"""

FORMAT_FLOAT64: typing.Any = ...

"""

Constant value 40

"""

FORMAT_INVALID: typing.Any = ...

"""

Constant value 0

"""

FORMAT_S16: typing.Any = ...

"""

Constant value 18

"""

FORMAT_S24: typing.Any = ...

"""

Constant value 19

"""

FORMAT_S32: typing.Any = ...

"""

Constant value 20

"""

FORMAT_U8: typing.Any = ...

"""

Constant value 1

"""

RATE_11025: typing.Any = ...

"""

Constant value 11025

"""

RATE_16000: typing.Any = ...

"""

Constant value 16000

"""

RATE_192000: typing.Any = ...

"""

Constant value 192000

"""

RATE_22050: typing.Any = ...

"""

Constant value 22050

"""

RATE_32000: typing.Any = ...

"""

Constant value 32000

"""

RATE_44100: typing.Any = ...

"""

Constant value 44100

"""

RATE_48000: typing.Any = ...

"""

Constant value 48000

"""

RATE_8000: typing.Any = ...

"""

Constant value 8000

"""

RATE_88200: typing.Any = ...

"""

Constant value 88200

"""

RATE_96000: typing.Any = ...

"""

Constant value 96000

"""

RATE_INVALID: typing.Any = ...

"""

Constant value 0

"""

STATUS_INVALID: typing.Any = ...

"""

Constant value 0

"""

STATUS_PAUSED: typing.Any = ...

"""

Constant value 2

"""

STATUS_PLAYING: typing.Any = ...

"""

Constant value 1

"""

STATUS_STOPPED: typing.Any = ...

"""

Constant value 3

"""

class Device:

  """

  Device objects represent an audio output backend like OpenAL or SDL, but might also represent a file output or RAM buffer output.

  """

  def lock(self) -> None:

    """

    Locks the device so that it's guaranteed, that no samples are
read from the streams until :meth:`unlock` is called.
This is useful if you want to do start/stop/pause/resume some
sounds at the same time.

    Note: The device has to be unlocked as often as locked to be
able to continue playback.

    Warning: Make sure the time between locking and unlocking is
as short as possible to avoid clicks.

    """

    ...

  def play(self, sound: Sound, keep: bool = False) -> Handle:

    """

    Plays a sound.

    """

    ...

  def stopAll(self) -> None:

    """

    Stops all playing and paused sounds.

    """

    ...

  def unlock(self) -> None:

    """

    Unlocks the device after a lock call, see :meth:`lock` for
details.

    """

    ...

  channels: typing.Any = ...

  """

  The channel count of the device.

  """

  distance_model: typing.Any = ...

  """

  The distance model of the device.

  `OpenAL Documentation <https://www.openal.org/documentation/>`_

  """

  doppler_factor: typing.Any = ...

  """

  The doppler factor of the device.
This factor is a scaling factor for the velocity vectors in doppler calculation. So a value bigger than 1 will exaggerate the effect as it raises the velocity.

  """

  format: typing.Any = ...

  """

  The native sample format of the device.

  """

  listener_location: typing.Any = ...

  """

  The listeners's location in 3D space, a 3D tuple of floats.

  """

  listener_orientation: typing.Any = ...

  """

  The listener's orientation in 3D space as quaternion, a 4 float tuple.

  """

  listener_velocity: typing.Any = ...

  """

  The listener's velocity in 3D space, a 3D tuple of floats.

  """

  rate: typing.Any = ...

  """

  The sampling rate of the device in Hz.

  """

  speed_of_sound: typing.Any = ...

  """

  The speed of sound of the device.
The speed of sound in air is typically 343.3 m/s.

  """

  volume: typing.Any = ...

  """

  The overall volume of the device.

  """

class DynamicMusic:

  """

  The DynamicMusic object allows to play music depending on a current scene, scene changes are managed by the class, with the possibility of custom transitions.
The default transition is a crossfade effect, and the default scene is silent and has id 0

  """

  def addScene(self, scene: Sound) -> int:

    """

    Adds a new scene.

    """

    ...

  def addTransition(self, ini: int, end: int, transition: Sound) -> bool:

    """

    Adds a new scene.

    """

    ...

  def pause(self) -> bool:

    """

    Pauses playback of the scene.

    """

    ...

  def resume(self) -> bool:

    """

    Resumes playback of the scene.

    """

    ...

  def stop(self) -> bool:

    """

    Stops playback of the scene.

    """

    ...

  fadeTime: typing.Any = ...

  """

  The length in seconds of the crossfade transition

  """

  position: typing.Any = ...

  """

  The playback position of the scene in seconds.

  """

  scene: typing.Any = ...

  """

  The current scene

  """

  status: typing.Any = ...

  """

  Whether the scene is playing, paused or stopped (=invalid).

  """

  volume: typing.Any = ...

  """

  The volume of the scene.

  """

class Handle:

  """

  Handle objects are playback handles that can be used to control playback of a sound. If a sound is played back multiple times then there are as many handles.

  """

  def pause(self) -> bool:

    """

    Pauses playback.

    """

    ...

  def resume(self) -> bool:

    """

    Resumes playback.

    """

    ...

  def stop(self) -> bool:

    """

    Stops playback.

    Note: This makes the handle invalid.

    """

    ...

  attenuation: typing.Any = ...

  """

  This factor is used for distance based attenuation of the source.

  :attr:`Device.distance_model`

  """

  cone_angle_inner: typing.Any = ...

  """

  The opening angle of the inner cone of the source. If the cone values of a source are set there are two (audible) cones with the apex at the :attr:`location` of the source and with infinite height, heading in the direction of the source's :attr:`orientation`.
In the inner cone the volume is normal. Outside the outer cone the volume will be :attr:`cone_volume_outer` and in the area between the volume will be interpolated linearly.

  """

  cone_angle_outer: typing.Any = ...

  """

  The opening angle of the outer cone of the source.

  :attr:`cone_angle_inner`

  """

  cone_volume_outer: typing.Any = ...

  """

  The volume outside the outer cone of the source.

  :attr:`cone_angle_inner`

  """

  distance_maximum: typing.Any = ...

  """

  The maximum distance of the source.
If the listener is further away the source volume will be 0.

  :attr:`Device.distance_model`

  """

  distance_reference: typing.Any = ...

  """

  The reference distance of the source.
At this distance the volume will be exactly :attr:`volume`.

  :attr:`Device.distance_model`

  """

  keep: typing.Any = ...

  """

  Whether the sound should be kept paused in the device when its end is reached.
This can be used to seek the sound to some position and start playback again.

  Warning: If this is set to true and you forget stopping this equals a memory leak as the handle exists until the device is destroyed.

  """

  location: typing.Any = ...

  """

  The source's location in 3D space, a 3D tuple of floats.

  """

  loop_count: typing.Any = ...

  """

  The (remaining) loop count of the sound. A negative value indicates infinity.

  """

  orientation: typing.Any = ...

  """

  The source's orientation in 3D space as quaternion, a 4 float tuple.

  """

  pitch: typing.Any = ...

  """

  The pitch of the sound.

  """

  position: typing.Any = ...

  """

  The playback position of the sound in seconds.

  """

  relative: typing.Any = ...

  """

  Whether the source's location, velocity and orientation is relative or absolute to the listener.

  """

  status: typing.Any = ...

  """

  Whether the sound is playing, paused or stopped (=invalid).

  """

  velocity: typing.Any = ...

  """

  The source's velocity in 3D space, a 3D tuple of floats.

  """

  volume: typing.Any = ...

  """

  The volume of the sound.

  """

  volume_maximum: typing.Any = ...

  """

  The maximum volume of the source.

  :attr:`Device.distance_model`

  """

  volume_minimum: typing.Any = ...

  """

  The minimum volume of the source.

  :attr:`Device.distance_model`

  """

class PlaybackManager:

  """

  A PlabackManager object allows to easily control groups os sounds organized in categories.

  """

  def addCategory(self, volume: float) -> int:

    """

    Adds a category with a custom volume.

    """

    ...

  def clean(self) -> None:

    """

    Cleans all the invalid and finished sound from the playback manager.

    """

    ...

  def getVolume(self, catKey: int) -> float:

    """

    Retrieves the volume of a category.

    """

    ...

  def pause(self, catKey: int) -> bool:

    """

    Pauses playback of the category.

    """

    ...

  def play(self, sound: Sound, catKey: int) -> Handle:

    """

    Plays a sound through the playback manager and assigns it to a category.

    """

    ...

  def resume(self, catKey: int) -> bool:

    """

    Resumes playback of the catgory.

    """

    ...

  def setVolume(self, volume: float, catKey: int) -> int:

    """

    Changes the volume of a category.

    """

    ...

  def stop(self, catKey: int) -> bool:

    """

    Stops playback of the category.

    """

    ...

class Sequence:

  """

  This sound represents sequenced entries to play a sound sequence.

  """

  def add(self) -> SequenceEntry:

    """

    Adds a new entry to the sequence.

    """

    ...

  def remove(self) -> None:

    """

    Removes an entry from the sequence.

    """

    ...

  def setAnimationData(self) -> None:

    """

    Writes animation data to a sequence.

    """

    ...

  channels: typing.Any = ...

  """

  The channel count of the sequence.

  """

  distance_model: typing.Any = ...

  """

  The distance model of the sequence.

  `OpenAL Documentation <https://www.openal.org/documentation/>`_

  """

  doppler_factor: typing.Any = ...

  """

  The doppler factor of the sequence.
This factor is a scaling factor for the velocity vectors in doppler calculation. So a value bigger than 1 will exaggerate the effect as it raises the velocity.

  """

  fps: typing.Any = ...

  """

  The listeners's location in 3D space, a 3D tuple of floats.

  """

  muted: typing.Any = ...

  """

  Whether the whole sequence is muted.

  """

  rate: typing.Any = ...

  """

  The sampling rate of the sequence in Hz.

  """

  speed_of_sound: typing.Any = ...

  """

  The speed of sound of the sequence.
The speed of sound in air is typically 343.3 m/s.

  """

class SequenceEntry:

  """

  SequenceEntry objects represent an entry of a sequenced sound.

  """

  def move(self) -> None:

    """

    Moves the entry.

    """

    ...

  def setAnimationData(self) -> None:

    """

    Writes animation data to a sequenced entry.

    """

    ...

  attenuation: typing.Any = ...

  """

  This factor is used for distance based attenuation of the source.

  :attr:`Device.distance_model`

  """

  cone_angle_inner: typing.Any = ...

  """

  The opening angle of the inner cone of the source. If the cone values of a source are set there are two (audible) cones with the apex at the :attr:`location` of the source and with infinite height, heading in the direction of the source's :attr:`orientation`.
In the inner cone the volume is normal. Outside the outer cone the volume will be :attr:`cone_volume_outer` and in the area between the volume will be interpolated linearly.

  """

  cone_angle_outer: typing.Any = ...

  """

  The opening angle of the outer cone of the source.

  :attr:`cone_angle_inner`

  """

  cone_volume_outer: typing.Any = ...

  """

  The volume outside the outer cone of the source.

  :attr:`cone_angle_inner`

  """

  distance_maximum: typing.Any = ...

  """

  The maximum distance of the source.
If the listener is further away the source volume will be 0.

  :attr:`Device.distance_model`

  """

  distance_reference: typing.Any = ...

  """

  The reference distance of the source.
At this distance the volume will be exactly :attr:`volume`.

  :attr:`Device.distance_model`

  """

  muted: typing.Any = ...

  """

  Whether the entry is muted.

  """

  relative: typing.Any = ...

  """

  Whether the source's location, velocity and orientation is relative or absolute to the listener.

  """

  sound: typing.Any = ...

  """

  The sound the entry is representing and will be played in the sequence.

  """

  volume_maximum: typing.Any = ...

  """

  The maximum volume of the source.

  :attr:`Device.distance_model`

  """

  volume_minimum: typing.Any = ...

  """

  The minimum volume of the source.

  :attr:`Device.distance_model`

  """

class Sound:

  """

  Sound objects are immutable and represent a sound that can be played simultaneously multiple times. They are called factories because they create reader objects internally that are used for playback.

  """

  @classmethod

  def buffer(cls, data: numpy.ndarray, rate: float) -> Sound:

    """

    Creates a sound from a data buffer.

    """

    ...

  @classmethod

  def file(cls, filename: str) -> Sound:

    """

    Creates a sound object of a sound file.

    Warning: If the file doesn't exist or can't be read you will
not get an exception immediately, but when you try to start
playback of that sound.

    """

    ...

  @classmethod

  def list(cls) -> Sound:

    """

    Creates an empty sound list that can contain several sounds.

    """

    ...

  @classmethod

  def sawtooth(cls, frequency: float, rate: int = 48000) -> Sound:

    """

    Creates a sawtooth sound which plays a sawtooth wave.

    """

    ...

  @classmethod

  def silence(cls, rate: int = 48000) -> Sound:

    """

    Creates a silence sound which plays simple silence.

    """

    ...

  @classmethod

  def sine(cls, frequency: float, rate: int = 48000) -> Sound:

    """

    Creates a sine sound which plays a sine wave.

    """

    ...

  @classmethod

  def square(cls, frequency: float, rate: int = 48000) -> Sound:

    """

    Creates a square sound which plays a square wave.

    """

    ...

  @classmethod

  def triangle(cls, frequency: float, rate: int = 48000) -> Sound:

    """

    Creates a triangle sound which plays a triangle wave.

    """

    ...

  def ADSR(self, attack: float, decay: float, sustain: float, release: float) -> Sound:

    """

    Attack-Decay-Sustain-Release envelopes the volume of a sound.
Note: there is currently no way to trigger the release with this API.

    """

    ...

  def accumulate(self, additive: typing.Any = False) -> Sound:

    """

    Accumulates a sound by summing over positive input
differences thus generating a monotonic sigal.
If additivity is set to true negative input differences get added too,
but positive ones with a factor of two.

    Note that with additivity the signal is not monotonic anymore.

    """

    ...

  def addSound(self, sound: Sound) -> None:

    """

    Adds a new sound to a sound list.

    Note: You can only add a sound to a sound list.

    """

    ...

  def cache(self) -> Sound:

    """

    Caches a sound into RAM.

    This saves CPU usage needed for decoding and file access if the
underlying sound reads from a file on the harddisk,
but it consumes a lot of memory.

    Note: Only known-length factories can be buffered.

    Warning: Raw PCM data needs a lot of space, only buffer
short factories.

    """

    ...

  def data(self) -> numpy.ndarray:

    """

    Retrieves the data of the sound as numpy array.

    Note: Best efficiency with cached sounds.

    """

    ...

  def delay(self, time: float) -> Sound:

    """

    Delays by playing adding silence in front of the other sound's data.

    """

    ...

  def envelope(self, attack: float, release: float, threshold: float, arthreshold: float) -> Sound:

    """

    Delays by playing adding silence in front of the other sound's data.

    """

    ...

  def fadein(self, start: float, length: float) -> Sound:

    """

    Fades a sound in by raising the volume linearly in the given
time interval.

    Note: Before the fade starts it plays silence.

    """

    ...

  def fadeout(self, start: float, length: float) -> Sound:

    """

    Fades a sound in by lowering the volume linearly in the given
time interval.

    Note: After the fade this sound plays silence, so that
the length of the sound is not altered.

    """

    ...

  def filter(self, b: typing.Sequence[float], a: typing.Sequence[float] = 1) -> Sound:

    """

    Filters a sound with the supplied IIR filter coefficients.
Without the second parameter you'll get a FIR filter.

    If the first value of the a sequence is 0,
it will be set to 1 automatically.
If the first value of the a sequence is neither 0 nor 1, all
filter coefficients will be scaled by this value so that it is 1
in the end, you don't have to scale yourself.

    """

    ...

  def highpass(self, frequency: float, Q: float = 0.5) -> Sound:

    """

    Creates a second order highpass filter based on the transfer
function H(s) = s^2 / (s^2 + s/Q + 1)

    """

    ...

  def join(self, sound: Sound) -> Sound:

    """

    Plays two factories in sequence.

    Note: The two factories have to have the same specifications
(channels and samplerate).

    """

    ...

  def limit(self, start: float, end: float) -> Sound:

    """

    Limits a sound within a specific start and end time.

    """

    ...

  def loop(self, count: int) -> Sound:

    """

    Loops a sound.

    Note: This is a filter function, you might consider using
:attr:`Handle.loop_count` instead.

    """

    ...

  def lowpass(self, frequency: float, Q: float = 0.5) -> Sound:

    """

    Creates a second order lowpass filter based on the transfer    function H(s) = 1 / (s^2 + s/Q + 1)

    """

    ...

  def mix(self, sound: Sound) -> Sound:

    """

    Mixes two factories.

    Note: The two factories have to have the same specifications
(channels and samplerate).

    """

    ...

  def modulate(self, sound: Sound) -> Sound:

    """

    Modulates two factories.

    Note: The two factories have to have the same specifications
(channels and samplerate).

    """

    ...

  def mutable(self) -> Sound:

    """

    Creates a sound that will be restarted when sought backwards.
If the original sound is a sound list, the playing sound can change.

    """

    ...

  def pingpong(self) -> Sound:

    """

    Plays a sound forward and then backward.
This is like joining a sound with its reverse.

    """

    ...

  def pitch(self, factor: float) -> Sound:

    """

    Changes the pitch of a sound with a specific factor.

    Note: This is done by changing the sample rate of the
underlying sound, which has to be an integer, so the factor
value rounded and the factor may not be 100 % accurate.

    Note: This is a filter function, you might consider using
:attr:`Handle.pitch` instead.

    """

    ...

  def rechannel(self, channels: int) -> Sound:

    """

    Rechannels the sound.

    """

    ...

  def resample(self, rate: float, high_quality: bool) -> Sound:

    """

    Resamples the sound.

    """

    ...

  def reverse(self) -> Sound:

    """

    Plays a sound reversed.

    Note: The sound has to have a finite length and has to be seekable.
It's recommended to use this only with factories with
fast and accurate seeking, which is not true for encoded audio
files, such ones should be buffered using :meth:`cache` before
being played reversed.

    Warning: If seeking is not accurate in the underlying sound
you'll likely hear skips/jumps/cracks.

    """

    ...

  def sum(self) -> Sound:

    """

    Sums the samples of a sound.

    """

    ...

  def threshold(self, threshold: float = 0) -> Sound:

    """

    Makes a threshold wave out of an audio wave by setting all samples
with a amplitude >= threshold to 1, all <= -threshold to -1 and
all between to 0.

    """

    ...

  def volume(self, volume: float) -> Sound:

    """

    Changes the volume of a sound.

    Note: Should be in the range [0, 1] to avoid clipping.

    Note: This is a filter function, you might consider using
:attr:`Handle.volume` instead.

    """

    ...

  def write(self, filename: str, rate: int, channels: int, format: int, container: int, codec: int, bitrate: int, buffersize: int) -> None:

    """

    Writes the sound to a file.

    """

    ...

  length: typing.Any = ...

  """

  The sample specification of the sound as a tuple with rate and channel count.

  """

  specs: typing.Any = ...

  """

  The sample specification of the sound as a tuple with rate and channel count.

  """

class Source:

  """

  The source object represents the source position of a binaural sound.

  """

  azimuth: typing.Any = ...

  """

  The azimuth angle.

  """

  distance: typing.Any = ...

  """

  The distance value. 0 is min, 1 is max.

  """

  elevation: typing.Any = ...

  """

  The elevation angle.

  """

class ThreadPool:

  """

  A ThreadPool is used to parallelize convolution efficiently.

  """

  ...

class error:

  ...



"""


Noise Utilities (mathutils.noise)
*********************************

The Blender noise module

:func:`cell`

:func:`cell_vector`

:func:`fractal`

:func:`hetero_terrain`

:func:`hybrid_multi_fractal`

:func:`multi_fractal`

:func:`noise`

:func:`noise_vector`

:func:`random`

:func:`random_unit_vector`

:func:`random_vector`

:func:`ridged_multi_fractal`

:func:`seed_set`

:func:`turbulence`

:func:`turbulence_vector`

:func:`variable_lacunarity`

:func:`voronoi`

"""

import typing

import mathutils

def cell(position: mathutils.Vector) -> float:

  """

  Returns cell noise value at the specified position.

  """

  ...

def cell_vector(position: mathutils.Vector) -> mathutils.Vector:

  """

  Returns cell noise vector at the specified position.

  """

  ...

def fractal(position: mathutils.Vector, H: float, lacunarity: float, octaves: int, noise_basis: str = 'PERLIN_ORIGINAL') -> float:

  """

  Returns the fractal Brownian motion (fBm) noise value from the noise basis at the specified position.

  """

  ...

def hetero_terrain(position: mathutils.Vector, H: float, lacunarity: float, octaves: int, offset: float, noise_basis: str = 'PERLIN_ORIGINAL') -> float:

  """

  Returns the heterogeneous terrain value from the noise basis at the specified position.

  """

  ...

def hybrid_multi_fractal(position: mathutils.Vector, H: float, lacunarity: float, octaves: int, offset: float, gain: float, noise_basis: str = 'PERLIN_ORIGINAL') -> float:

  """

  Returns hybrid multifractal value from the noise basis at the specified position.

  """

  ...

def multi_fractal(position: mathutils.Vector, H: float, lacunarity: float, octaves: int, noise_basis: str = 'PERLIN_ORIGINAL') -> float:

  """

  Returns multifractal noise value from the noise basis at the specified position.

  """

  ...

def noise(position: mathutils.Vector, noise_basis: str = 'PERLIN_ORIGINAL') -> float:

  """

  Returns noise value from the noise basis at the position specified.

  """

  ...

def noise_vector(position: mathutils.Vector, noise_basis: str = 'PERLIN_ORIGINAL') -> mathutils.Vector:

  """

  Returns the noise vector from the noise basis at the specified position.

  """

  ...

def random() -> float:

  """

  Returns a random number in the range [0, 1).

  """

  ...

def random_unit_vector(size: int = 3) -> mathutils.Vector:

  """

  Returns a unit vector with random entries.

  """

  ...

def random_vector(size: int = 3) -> mathutils.Vector:

  """

  Returns a vector with random entries in the range (-1, 1).

  """

  ...

def ridged_multi_fractal(position: mathutils.Vector, H: float, lacunarity: float, octaves: int, offset: float, gain: float, noise_basis: str = 'PERLIN_ORIGINAL') -> float:

  """

  Returns ridged multifractal value from the noise basis at the specified position.

  """

  ...

def seed_set(seed: int) -> None:

  """

  Sets the random seed used for random_unit_vector, and random.

  """

  ...

def turbulence(position: mathutils.Vector, octaves: int, hard: bool, noise_basis: str = 'PERLIN_ORIGINAL', amplitude_scale: float = 0.5, frequency_scale: float = 2.0) -> float:

  """

  Returns the turbulence value from the noise basis at the specified position.

  """

  ...

def turbulence_vector(position: mathutils.Vector, octaves: int, hard: bool, noise_basis: str = 'PERLIN_ORIGINAL', amplitude_scale: float = 0.5, frequency_scale: float = 2.0) -> mathutils.Vector:

  """

  Returns the turbulence vector from the noise basis at the specified position.

  """

  ...

def variable_lacunarity(position: mathutils.Vector, distortion: float, noise_type1: str = 'PERLIN_ORIGINAL', noise_type2: str = 'PERLIN_ORIGINAL') -> float:

  """

  Returns variable lacunarity noise value, a distorted variety of noise, from noise type 1 distorted by noise type 2 at the specified position.

  """

  ...

def voronoi(position: mathutils.Vector, distance_metric: str = 'DISTANCE', exponent: float = 2.5) -> typing.List[typing.Any]:

  """

  Returns a list of distances to the four closest features and their locations.

  """

  ...



"""


Image Color Mode Items
^^^^^^^^^^^^^^^^^^^^^^

:BW:              
  BW.

  Images get saved in 8-bit grayscale (only PNG, JPEG, TGA, TIF).

:RGB:             
  RGB.

  Images are saved with RGB (color) data.

:RGBA:            
  RGBA.

  Images are saved with RGB and Alpha data (if supported).

.. _rna-enum-image-color-mode-items:

"""

import typing



"""


Fmodifier Type Items
^^^^^^^^^^^^^^^^^^^^

:nullptr:         
  Invalid.

:GENERATOR:       
  Generator.

  Generate a curve using a factorized or expanded polynomial.

:FNGENERATOR:     
  Built-In Function.

  Generate a curve using standard math functions such as sin and cos.

:ENVELOPE:        
  Envelope.

  Reshape F-Curve values, e.g. change amplitude of movements.

:CYCLES:          
  Cycles.

  Cyclic extend/repeat keyframe sequence.

:NOISE:           
  Noise.

  Add pseudo-random noise on top of F-Curves.

:LIMITS:          
  Limits.

  Restrict maximum and minimum values of F-Curve.

:STEPPED:         
  Stepped Interpolation.

  Snap values to nearest grid step, e.g. for a stop-motion look.

.. _rna-enum-fmodifier-type-items:

"""

import typing



"""


Screen Operators
****************

:func:`actionzone`

:func:`animation_cancel`

:func:`animation_play`

:func:`animation_step`

:func:`area_close`

:func:`area_dupli`

:func:`area_join`

:func:`area_move`

:func:`area_options`

:func:`area_split`

:func:`area_swap`

:func:`back_to_previous`

:func:`delete`

:func:`drivers_editor_show`

:func:`frame_jump`

:func:`frame_offset`

:func:`header_toggle_menus`

:func:`info_log_show`

:func:`keyframe_jump`

:func:`marker_jump`

:func:`new`

:func:`redo_last`

:func:`region_blend`

:func:`region_context_menu`

:func:`region_flip`

:func:`region_quadview`

:func:`region_scale`

:func:`region_toggle`

:func:`repeat_history`

:func:`repeat_last`

:func:`screen_full_area`

:func:`screen_set`

:func:`screenshot`

:func:`screenshot_area`

:func:`space_context_cycle`

:func:`space_type_set_or_cycle`

:func:`spacedata_cleanup`

:func:`userpref_show`

:func:`workspace_cycle`

"""

import typing

def actionzone(modifier: int = 0) -> None:

  """

  Handle area action zones for mouse actions/gestures

  """

  ...

def animation_cancel(restore_frame: bool = True) -> None:

  """

  Cancel animation, returning to the original frame

  """

  ...

def animation_play(reverse: bool = False, sync: bool = False) -> None:

  """

  Play animation

  """

  ...

def animation_step() -> None:

  """

  Step through animation by position

  """

  ...

def area_close() -> None:

  """

  Close selected area

  """

  ...

def area_dupli() -> None:

  """

  Duplicate selected area into new window

  """

  ...

def area_join(cursor: typing.Tuple[int, int] = (0, 0)) -> None:

  """

  Join selected areas into new window

  """

  ...

def area_move(x: int = 0, y: int = 0, delta: int = 0) -> None:

  """

  Move selected area edges

  """

  ...

def area_options() -> None:

  """

  Operations for splitting and merging

  """

  ...

def area_split(direction: str = 'HORIZONTAL', factor: float = 0.5, cursor: typing.Tuple[int, int] = (0, 0)) -> None:

  """

  Split selected area into new windows

  """

  ...

def area_swap(cursor: typing.Tuple[int, int] = (0, 0)) -> None:

  """

  Swap selected areas screen positions

  """

  ...

def back_to_previous() -> None:

  """

  Revert back to the original screen layout, before fullscreen area overlay

  """

  ...

def delete() -> None:

  """

  Delete active screen

  """

  ...

def drivers_editor_show() -> None:

  """

  Show drivers editor in a separate window

  """

  ...

def frame_jump(end: bool = False) -> None:

  """

  Jump to first/last frame in frame range

  """

  ...

def frame_offset(delta: int = 0) -> None:

  """

  Move current frame forward/backward by a given number

  """

  ...

def header_toggle_menus() -> None:

  """

  Expand or collapse the header pulldown menus

  """

  ...

def info_log_show() -> None:

  """

  Show info log in a separate window

  """

  ...

def keyframe_jump(next: bool = True) -> None:

  """

  Jump to previous/next keyframe

  """

  ...

def marker_jump(next: bool = True) -> None:

  """

  Jump to previous/next marker

  """

  ...

def new() -> None:

  """

  Add a new screen

  """

  ...

def redo_last() -> None:

  """

  Display parameters for last action performed

  """

  ...

def region_blend() -> None:

  """

  Blend in and out overlapping region

  """

  ...

def region_context_menu() -> None:

  """

  Display region context menu

  """

  ...

def region_flip() -> None:

  """

  Toggle the region's alignment (left/right or top/bottom)

  """

  ...

def region_quadview() -> None:

  """

  Split selected area into camera, front, right, and top views

  """

  ...

def region_scale() -> None:

  """

  Scale selected area

  """

  ...

def region_toggle(region_type: str = 'WINDOW') -> None:

  """

  Hide or unhide the region

  """

  ...

def repeat_history(index: int = 0) -> None:

  """

  Display menu for previous actions performed

  """

  ...

def repeat_last() -> None:

  """

  Repeat last action

  """

  ...

def screen_full_area(use_hide_panels: bool = False) -> None:

  """

  Toggle display selected area as fullscreen/maximized

  """

  ...

def screen_set(delta: int = 1) -> None:

  """

  Cycle through available screens

  """

  ...

def screenshot(filepath: str = '', hide_props_region: bool = True, check_existing: bool = True, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = True, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, show_multiview: bool = False, use_multiview: bool = False, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Capture a picture of the whole Blender window

  """

  ...

def screenshot_area(filepath: str = '', hide_props_region: bool = True, check_existing: bool = True, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = True, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, show_multiview: bool = False, use_multiview: bool = False, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Capture a picture of an editor

  """

  ...

def space_context_cycle(direction: str = 'NEXT') -> None:

  """

  Cycle through the editor context by activating the next/previous one

  """

  ...

def space_type_set_or_cycle(space_type: str = 'EMPTY') -> None:

  """

  Set the space type or cycle subtype

  """

  ...

def spacedata_cleanup() -> None:

  """

  Remove unused settings for invisible editors

  """

  ...

def userpref_show(section: str = 'INTERFACE') -> None:

  """

  Edit user preferences and system settings

  """

  ...

def workspace_cycle(direction: str = 'NEXT') -> None:

  """

  Cycle through workspaces

  """

  ...



"""


Blender as a Python Module
^^^^^^^^^^^^^^^^^^^^^^^^^^

Blender supports being built as a Python module,
allowing ``import bpy`` to be added to any Python script, providing access to Blender's features.

Note: At time of writing official builds are not available,
using this requires compiling Blender yourself see
`build instructions <https://wiki.blender.org/w/index.php?title=Building_Blender/Other/BlenderAsPyModule>`_.


Use Cases
*********

Python developers may wish to integrate Blender scripts which don't center around Blender.

Possible uses include:

* Visualizing data by rendering images and animations.

* Image processing using Blender's compositor.

* Video editing (using Blender's sequencer).

* 3D file conversion.

* Development, accessing ``bpy`` from Python IDE's and debugging tools for example.

* Automation.


Usage
*****

For the most part using Blender as a Python module is equivalent to running a script in background-mode
(passing the command-line arguments ``--background`` or ``-b``),
however there are some differences to be aware of.

Blender's Executable Access
  The attribute :class:`bpy.app.binary_path` defaults to an empty string.

  If you wish to point this to the location of a known executable you may set the value.

  This example searches for the binary, setting it when found:

  .. code:: python

    import bpy
    import shutil

    blender_bin = shutil.which("blender")
    if blender_bin:
       print("Found:", blender_bin)
       bpy.app.binary_path = blender_bin
    else:
       print("Unable to find blender!")

Blender's Internal Modules
  There are many modules included with Blender such as :mod:`gpu` and :mod:`mathuils`.
It's important that these are imported after ``bpy`` or they will not be found.

Command Line Arguments Unsupported
  Functionality controlled by command line arguments (shown by calling ``blender --help`` aren't accessible).

  Typically this isn't such a limitation although there are some command line arguments that don't have
equivalents in Blender's Python API (``--threads`` and ``--log`` for example).

  Note: Access to these settings may be added in the future as needed.

Resource Sharing (GPU)
  It's possible other Python modules make use of the GPU in a way that prevents Blender/Cycles from accessing the GPU.

Signal Handlers
  Blender's typical signal handlers are not initialized, so there is no special handling for ``Control-C``
to cancel a render and a crash log is not written in the event of a crash.

Startup and Preferences
  When the ``bpy`` module loads it contains the default startup scene
(instead of an "empty" blend-file as you might expect), so there is a default cube, camera and light.

  If you wish to start from an empty file use: ``bpy.ops.wm.read_factory_settings(use_empty=True)``.

  The users startup and preferences are ignored to prevent your local configuration from impacting scripts behavior.
The Python module behaves as if ``--factory-startup`` was passed as a command line argument.

  The users preferences and startup can be loaded using operators:

  .. code:: python

    import bpy

    bpy.ops.wm.read_userpref()
    bpy.ops.wm.read_homefile()


Limitations
***********

Most constraints of Blender as an application still apply:

Reloading Unsupported
  Reloading the ``bpy`` module via ``importlib.reload`` will raise an exception
instead of reloading and resetting the module.

  Instead, the operator ``bpy.ops.wm.read_factory_settings()`` can be used to reset the internal state.

Single Blend File Restriction
  Only a single ``.blend`` file can be edited at a time.

  Hint: As with the application it's possible to start multiple instances,
each with their own ``bpy`` and therefor Blender state.
Python provides the ``multiprocessing`` module to make communicating with sub-processes more convenient.In some cases the library API may be an alternative to starting separate processes,
although this API operates on reading and writing ID data-blocks and isn't
a complete substitute for loading ``.blend`` files, see:

    * :meth:`bpy.types.BlendDataLibraries.load`

    * :meth:`bpy.types.BlendDataLibraries.write`

    * :meth:`bpy.types.BlendData.temp_data`
supports a temporary data-context to avoid manipulating the current ``.blend`` file.

"""

import typing



"""


Text Operators
**************

:func:`autocomplete`

:func:`comment_toggle`

:func:`convert_whitespace`

:func:`copy`

:func:`cursor_set`

:func:`cut`

:func:`delete`

:func:`duplicate_line`

:func:`find`

:func:`find_set_selected`

:func:`indent`

:func:`indent_or_autocomplete`

:func:`insert`

:func:`jump`

:func:`jump_to_file_at_point`

:func:`jump_to_file_at_point_internal`

:func:`line_break`

:func:`line_number`

:func:`make_internal`

:func:`move`

:func:`move_lines`

:func:`move_select`

:func:`new`

:func:`open`

:func:`overwrite_toggle`

:func:`paste`

:func:`refresh_pyconstraints`

:func:`reload`

:func:`replace`

:func:`replace_set_selected`

:func:`resolve_conflict`

:func:`run_script`

:func:`save`

:func:`save_as`

:func:`scroll`

:func:`scroll_bar`

:func:`select_all`

:func:`select_line`

:func:`select_word`

:func:`selection_set`

:func:`start_find`

:func:`to_3d_object`

:func:`unindent`

:func:`unlink`

"""

import typing

def autocomplete() -> None:

  """

  Show a list of used text in the open document

  """

  ...

def comment_toggle(type: str = 'TOGGLE') -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/>`_.

  """

  ...

def convert_whitespace(type: str = 'SPACES') -> None:

  """

  Convert whitespaces by type

  """

  ...

def copy() -> None:

  """

  Copy selected text to clipboard

  """

  ...

def cursor_set(x: int = 0, y: int = 0) -> None:

  """

  Set cursor position

  """

  ...

def cut() -> None:

  """

  Cut selected text to clipboard

  """

  ...

def delete(type: str = 'NEXT_CHARACTER') -> None:

  """

  Delete text by cursor position

  """

  ...

def duplicate_line() -> None:

  """

  Duplicate the current line

  """

  ...

def find() -> None:

  """

  Find specified text

  """

  ...

def find_set_selected() -> None:

  """

  Find specified text and set as selected

  """

  ...

def indent() -> None:

  """

  Indent selected text

  """

  ...

def indent_or_autocomplete() -> None:

  """

  Indent selected text or autocomplete

  """

  ...

def insert(text: str = '') -> None:

  """

  Insert text at cursor position

  """

  ...

def jump(line: int = 1) -> None:

  """

  Jump cursor to line

  """

  ...

def jump_to_file_at_point(filepath: str = '', line: int = 0, column: int = 0) -> None:

  """

  Edit text file in external text editor

  """

  ...

def jump_to_file_at_point_internal(filepath: str = '', line: int = 0, column: int = 0) -> None:

  """

  Jump to a file for the internal text editor

  """

  ...

def line_break() -> None:

  """

  Insert line break at cursor position

  """

  ...

def line_number() -> None:

  """

  The current line number

  """

  ...

def make_internal() -> None:

  """

  Make active text file internal

  """

  ...

def move(type: str = 'LINE_BEGIN') -> None:

  """

  Move cursor to position type

  """

  ...

def move_lines(direction: str = 'DOWN') -> None:

  """

  Move the currently selected line(s) up/down

  """

  ...

def move_select(type: str = 'LINE_BEGIN') -> None:

  """

  Move the cursor while selecting

  """

  ...

def new() -> None:

  """

  Create a new text data-block

  """

  ...

def open(filepath: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = True, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = True, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, display_type: str = 'DEFAULT', sort_method: str = '', internal: bool = False) -> None:

  """

  Open a new text data-block

  """

  ...

def overwrite_toggle() -> None:

  """

  Toggle overwrite while typing

  """

  ...

def paste(selection: bool = False) -> None:

  """

  Paste text from clipboard

  """

  ...

def refresh_pyconstraints() -> None:

  """

  Refresh all pyconstraints

  """

  ...

def reload() -> None:

  """

  Reload active text data-block from its file

  """

  ...

def replace(all: bool = False) -> None:

  """

  Replace text with the specified text

  """

  ...

def replace_set_selected() -> None:

  """

  Replace text with specified text and set as selected

  """

  ...

def resolve_conflict(resolution: str = 'IGNORE') -> None:

  """

  When external text is out of sync, resolve the conflict

  """

  ...

def run_script() -> None:

  """

  Run active script

  """

  ...

def save() -> None:

  """

  Save active text data-block

  """

  ...

def save_as(filepath: str = '', hide_props_region: bool = True, check_existing: bool = True, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = True, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = True, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Save active text file with options

  """

  ...

def scroll(lines: int = 1) -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/>`_.

  """

  ...

def scroll_bar(lines: int = 1) -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/>`_.

  """

  ...

def select_all() -> None:

  """

  Select all text

  """

  ...

def select_line() -> None:

  """

  Select text by line

  """

  ...

def select_word() -> None:

  """

  Select word under cursor

  """

  ...

def selection_set() -> None:

  """

  Set text selection

  """

  ...

def start_find() -> None:

  """

  Start searching text

  """

  ...

def to_3d_object(split_lines: bool = False) -> None:

  """

  Create 3D text object from active text data-block

  """

  ...

def unindent() -> None:

  """

  Unindent selected text

  """

  ...

def unlink() -> None:

  """

  Unlink active text data-block

  """

  ...



"""


Curves Types
^^^^^^^^^^^^

:CATMULL_ROM:     
  Catmull Rom.

:POLY:            
  Poly.

:BEZIER:          
  Bezier.

:NURBS:           
  NURBS.

.. _rna-enum-curves-types:

"""

import typing



"""


Nla Mode Extend Items
^^^^^^^^^^^^^^^^^^^^^

:NOTHING:         
  Nothing.

  Strip has no influence past its extents.

:HOLD:            
  Hold.

  Hold the first frame if no previous strips in track, and always hold last frame.

:HOLD_FORWARD:    
  Hold Forward.

  Only hold last frame.

.. _rna-enum-nla-mode-extend-items:

"""

import typing



"""


Ui Operators
************

:func:`assign_default_button`

:func:`button_execute`

:func:`button_string_clear`

:func:`copy_as_driver_button`

:func:`copy_data_path_button`

:func:`copy_python_command_button`

:func:`copy_to_selected_button`

:func:`drop_color`

:func:`drop_material`

:func:`drop_name`

:func:`editsource`

:func:`edittranslation_init`

:func:`eyedropper_color`

:func:`eyedropper_colorramp`

:func:`eyedropper_colorramp_point`

:func:`eyedropper_depth`

:func:`eyedropper_driver`

:func:`eyedropper_gpencil_color`

:func:`eyedropper_id`

:func:`jump_to_target_button`

:func:`list_start_filter`

:func:`override_idtemplate_clear`

:func:`override_idtemplate_make`

:func:`override_idtemplate_reset`

:func:`override_remove_button`

:func:`override_type_set_button`

:func:`reloadtranslation`

:func:`reset_default_button`

:func:`unset_property_button`

:func:`view_drop`

:func:`view_item_rename`

:func:`view_start_filter`

"""

import typing

import mathutils

def assign_default_button() -> None:

  """

  Set this property's current value as the new default

  """

  ...

def button_execute(skip_depressed: bool = False) -> None:

  """

  Presses active button

  """

  ...

def button_string_clear() -> None:

  """

  Unsets the text of the active button

  """

  ...

def copy_as_driver_button() -> None:

  """

  Create a new driver with this property as input, and copy it to the internal clipboard. Use Paste Driver to add it to the target property, or Paste Driver Variables to extend an existing driver

  """

  ...

def copy_data_path_button(full_path: bool = False) -> None:

  """

  Copy the RNA data path for this property to the clipboard

  """

  ...

def copy_python_command_button() -> None:

  """

  Copy the Python command matching this button

  """

  ...

def copy_to_selected_button(all: bool = True) -> None:

  """

  Copy the property's value from the active item to the same property of all selected items if the same property exists

  """

  ...

def drop_color(color: mathutils.Color = (0.0, 0.0, 0.0), gamma: bool = False) -> None:

  """

  Drop colors to buttons

  """

  ...

def drop_material(session_uuid: int = 0) -> None:

  """

  Drag material to Material slots in Properties

  """

  ...

def drop_name(string: str = '') -> None:

  """

  Drop name to button

  """

  ...

def editsource() -> None:

  """

  Edit UI source code of the active button

  """

  ...

def edittranslation_init() -> None:

  """

  Edit i18n in current language for the active button

  """

  ...

def eyedropper_color() -> None:

  """

  Sample a color from the Blender window to store in a property

  """

  ...

def eyedropper_colorramp() -> None:

  """

  Sample a color band

  """

  ...

def eyedropper_colorramp_point() -> None:

  """

  Point-sample a color band

  """

  ...

def eyedropper_depth() -> None:

  """

  Sample depth from the 3D view

  """

  ...

def eyedropper_driver(mapping_type: str = 'SINGLE_MANY') -> None:

  """

  Pick a property to use as a driver target

  """

  ...

def eyedropper_gpencil_color(mode: str = 'MATERIAL') -> None:

  """

  Sample a color from the Blender Window and create Grease Pencil material

  """

  ...

def eyedropper_id() -> None:

  """

  Sample a data-block from the 3D View to store in a property

  """

  ...

def jump_to_target_button() -> None:

  """

  Switch to the target object or bone

  """

  ...

def list_start_filter() -> None:

  """

  Start entering filter text for the list in focus

  """

  ...

def override_idtemplate_clear() -> None:

  """

  Delete the selected local override and relink its usages to the linked data-block if possible, else reset it and mark it as non editable

  """

  ...

def override_idtemplate_make() -> None:

  """

  Create a local override of the selected linked data-block, and its hierarchy of dependencies

  """

  ...

def override_idtemplate_reset() -> None:

  """

  Reset the selected local override to its linked reference values

  """

  ...

def override_remove_button(all: bool = True) -> None:

  """

  Remove an override operation

  """

  ...

def override_type_set_button(all: bool = True, type: str = 'REPLACE') -> None:

  """

  Create an override operation, or set the type of an existing one

  """

  ...

def reloadtranslation() -> None:

  """

  Force a full reload of UI translation

  """

  ...

def reset_default_button(all: bool = True) -> None:

  """

  Reset this property's value to its default value

  """

  ...

def unset_property_button() -> None:

  """

  Clear the property and use default or generated value in operators

  """

  ...

def view_drop() -> None:

  """

  Drag and drop onto a data-set or item within the data-set

  """

  ...

def view_item_rename() -> None:

  """

  Rename the active item in the data-set view

  """

  ...

def view_start_filter() -> None:

  """

  Start entering filter text for the data-set in focus

  """

  ...



"""


GPU Platform Utilities (gpu.platform)
*************************************

This module provides access to GPU Platform definitions.

:func:`backend_type_get`

:func:`device_type_get`

:func:`renderer_get`

:func:`vendor_get`

:func:`version_get`

"""

import typing

def backend_type_get() -> str:

  """

  Get actuve GPU backend.

  """

  ...

def device_type_get() -> str:

  """

  Get GPU device type.

  """

  ...

def renderer_get() -> str:

  """

  Get GPU to be used for rendering.

  """

  ...

def vendor_get() -> str:

  """

  Get GPU vendor.

  """

  ...

def version_get() -> str:

  """

  Get GPU driver version.

  """

  ...



"""


Beztriple Interpolation Easing Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:AUTO:            
  Automatic Easing.

  Easing type is chosen automatically based on what the type of interpolation used (e.g. Ease In for transitional types, and Ease Out for dynamic effects).

:EASE_IN:         
  Ease In.

  Only on the end closest to the next keyframe.

:EASE_OUT:        
  Ease Out.

  Only on the end closest to the first keyframe.

:EASE_IN_OUT:     
  Ease In and Out.

  Segment between both keyframes.

.. _rna-enum-beztriple-interpolation-easing-items:

"""

import typing



"""


Sequence Modifier Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:BRIGHT_CONTRAST: 
  Brightness/Contrast.

:COLOR_BALANCE:   
  Color Balance.

:CURVES:          
  Curves.

:HUE_CORRECT:     
  Hue Correct.

:MASK:            
  Mask.

:TONEMAP:         
  Tone Map.

:WHITE_BALANCE:   
  White Balance.

.. _rna-enum-sequence-modifier-type-items:

"""

import typing



"""


Beztriple Keyframe Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:KEYFRAME:        
  Keyframe.

  Normal keyframe, e.g. for key poses.

:BREAKDOWN:       
  Breakdown.

  A breakdown pose, e.g. for transitions between key poses.

:MOVING_HOLD:     
  Moving Hold.

  A keyframe that is part of a moving hold.

:EXTREME:         
  Extreme.

  An "extreme" pose, or some other purpose as needed.

:JITTER:          
  Jitter.

  A filler or baked keyframe for keying on ones, or some other purpose as needed.

.. _rna-enum-beztriple-keyframe-type-items:

"""

import typing
